# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file '/home/grossmj/PycharmProjects/gns3-gui/gns3/ui/main_window.ui'
#
# Created: Mon Mar  9 17:21:40 2015
#      by: PyQt4 UI code generator 4.10.4
#
# WARNING! All changes made in this file will be lost!

from PyQt4 import QtCore, QtGui

try:
    _fromUtf8 = QtCore.QString.fromUtf8
except AttributeError:
    def _fromUtf8(s):
        return s

try:
    _encoding = QtGui.QApplication.UnicodeUTF8
    def _translate(context, text, disambig):
        return QtGui.QApplication.translate(context, text, disambig, _encoding)
except AttributeError:
    def _translate(context, text, disambig):
        return QtGui.QApplication.translate(context, text, disambig)

class Ui_MainWindow(object):
    def setupUi(self, MainWindow):
        MainWindow.setObjectName(_fromUtf8("MainWindow"))
        MainWindow.setWindowModality(QtCore.Qt.NonModal)
        MainWindow.resize(984, 715)
        MainWindow.setContextMenuPolicy(QtCore.Qt.PreventContextMenu)
        MainWindow.setStyleSheet(_fromUtf8("#toolBar_Devices QToolButton {\n"
"width: 50px;\n"
"height: 55px;\n"
"border:solid 1px black opacity 0.4;\n"
"background-none;\n"
"}\n"
"\n"
"#toolBar_General QToolButton {\n"
"width: 36px;\n"
"height: 36px;\n"
"border:solid 1px black opacity 0.4;\n"
"background-none;\n"
"}\n"
"\n"
""))
        MainWindow.setDockOptions(QtGui.QMainWindow.AllowTabbedDocks|QtGui.QMainWindow.AnimatedDocks)
        MainWindow.setUnifiedTitleAndToolBarOnMac(False)
        self.uiCentralWidget = QtGui.QWidget(MainWindow)
        self.uiCentralWidget.setObjectName(_fromUtf8("uiCentralWidget"))
        self.gridlayout = QtGui.QGridLayout(self.uiCentralWidget)
        self.gridlayout.setMargin(0)
        self.gridlayout.setSpacing(0)
        self.gridlayout.setObjectName(_fromUtf8("gridlayout"))
        self.uiGraphicsView = GraphicsView(self.uiCentralWidget)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.uiGraphicsView.sizePolicy().hasHeightForWidth())
        self.uiGraphicsView.setSizePolicy(sizePolicy)
        self.uiGraphicsView.setObjectName(_fromUtf8("uiGraphicsView"))
        self.gridlayout.addWidget(self.uiGraphicsView, 0, 0, 1, 1)
        MainWindow.setCentralWidget(self.uiCentralWidget)
        self.uiMenuBar = QtGui.QMenuBar(MainWindow)
        self.uiMenuBar.setGeometry(QtCore.QRect(0, 0, 984, 25))
        self.uiMenuBar.setObjectName(_fromUtf8("uiMenuBar"))
        self.uiEditMenu = QtGui.QMenu(self.uiMenuBar)
        self.uiEditMenu.setObjectName(_fromUtf8("uiEditMenu"))
        self.uiFileMenu = QtGui.QMenu(self.uiMenuBar)
        self.uiFileMenu.setObjectName(_fromUtf8("uiFileMenu"))
        self.uiHelpMenu = QtGui.QMenu(self.uiMenuBar)
        self.uiHelpMenu.setObjectName(_fromUtf8("uiHelpMenu"))
        self.uiViewMenu = QtGui.QMenu(self.uiMenuBar)
        self.uiViewMenu.setObjectName(_fromUtf8("uiViewMenu"))
        self.uiDocksMenu = QtGui.QMenu(self.uiViewMenu)
        self.uiDocksMenu.setObjectName(_fromUtf8("uiDocksMenu"))
        self.uiControlMenu = QtGui.QMenu(self.uiMenuBar)
        self.uiControlMenu.setObjectName(_fromUtf8("uiControlMenu"))
        self.uiAnnotateMenu = QtGui.QMenu(self.uiMenuBar)
        self.uiAnnotateMenu.setObjectName(_fromUtf8("uiAnnotateMenu"))
        self.uiDeviceMenu = QtGui.QMenu(self.uiMenuBar)
        self.uiDeviceMenu.setObjectName(_fromUtf8("uiDeviceMenu"))
        self.uiToolsMenu = QtGui.QMenu(self.uiMenuBar)
        self.uiToolsMenu.setObjectName(_fromUtf8("uiToolsMenu"))
        MainWindow.setMenuBar(self.uiMenuBar)
        self.uiStatusBar = QtGui.QStatusBar(MainWindow)
        self.uiStatusBar.setObjectName(_fromUtf8("uiStatusBar"))
        MainWindow.setStatusBar(self.uiStatusBar)
        self.uiGeneralToolBar = QtGui.QToolBar(MainWindow)
        self.uiGeneralToolBar.setToolTip(_fromUtf8(""))
        self.uiGeneralToolBar.setStatusTip(_fromUtf8(""))
        self.uiGeneralToolBar.setOrientation(QtCore.Qt.Horizontal)
        self.uiGeneralToolBar.setIconSize(QtCore.QSize(32, 32))
        self.uiGeneralToolBar.setObjectName(_fromUtf8("uiGeneralToolBar"))
        MainWindow.addToolBar(QtCore.Qt.TopToolBarArea, self.uiGeneralToolBar)
        self.uiNodesDockWidget = QtGui.QDockWidget(MainWindow)
        self.uiNodesDockWidget.setEnabled(True)
        self.uiNodesDockWidget.setVisible(True)
        self.uiNodesDockWidget.setFloating(False)
        self.uiNodesDockWidget.setAllowedAreas(QtCore.Qt.LeftDockWidgetArea|QtCore.Qt.RightDockWidgetArea)
        self.uiNodesDockWidget.setObjectName(_fromUtf8("uiNodesDockWidget"))
        self.uiNodesDockWidgetContents = QtGui.QWidget()
        self.uiNodesDockWidgetContents.setObjectName(_fromUtf8("uiNodesDockWidgetContents"))
        self.vboxlayout = QtGui.QVBoxLayout(self.uiNodesDockWidgetContents)
        self.vboxlayout.setSpacing(0)
        self.vboxlayout.setMargin(0)
        self.vboxlayout.setObjectName(_fromUtf8("vboxlayout"))
        self.uiNodesView = NodesView(self.uiNodesDockWidgetContents)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.uiNodesView.sizePolicy().hasHeightForWidth())
        self.uiNodesView.setSizePolicy(sizePolicy)
        self.uiNodesView.setDragEnabled(False)
        self.uiNodesView.setIconSize(QtCore.QSize(32, 32))
        self.uiNodesView.setRootIsDecorated(False)
        self.uiNodesView.setObjectName(_fromUtf8("uiNodesView"))
        self.uiNodesView.header().setVisible(False)
        self.vboxlayout.addWidget(self.uiNodesView)
        self.uiNodesDockWidget.setWidget(self.uiNodesDockWidgetContents)
        MainWindow.addDockWidget(QtCore.Qt.DockWidgetArea(1), self.uiNodesDockWidget)
        self.uiBrowsersToolBar = QtGui.QToolBar(MainWindow)
        self.uiBrowsersToolBar.setIconSize(QtCore.QSize(48, 48))
        self.uiBrowsersToolBar.setToolButtonStyle(QtCore.Qt.ToolButtonIconOnly)
        self.uiBrowsersToolBar.setObjectName(_fromUtf8("uiBrowsersToolBar"))
        MainWindow.addToolBar(QtCore.Qt.LeftToolBarArea, self.uiBrowsersToolBar)
        self.uiControlToolBar = QtGui.QToolBar(MainWindow)
        self.uiControlToolBar.setIconSize(QtCore.QSize(32, 32))
        self.uiControlToolBar.setToolButtonStyle(QtCore.Qt.ToolButtonIconOnly)
        self.uiControlToolBar.setObjectName(_fromUtf8("uiControlToolBar"))
        MainWindow.addToolBar(QtCore.Qt.TopToolBarArea, self.uiControlToolBar)
        self.uiConsoleDockWidget = QtGui.QDockWidget(MainWindow)
        self.uiConsoleDockWidget.setMaximumSize(QtCore.QSize(524287, 524287))
        self.uiConsoleDockWidget.setAllowedAreas(QtCore.Qt.AllDockWidgetAreas)
        self.uiConsoleDockWidget.setObjectName(_fromUtf8("uiConsoleDockWidget"))
        self.uiConsoleDockWidgetContents = QtGui.QWidget()
        self.uiConsoleDockWidgetContents.setObjectName(_fromUtf8("uiConsoleDockWidgetContents"))
        self.vboxlayout1 = QtGui.QVBoxLayout(self.uiConsoleDockWidgetContents)
        self.vboxlayout1.setSpacing(0)
        self.vboxlayout1.setMargin(0)
        self.vboxlayout1.setObjectName(_fromUtf8("vboxlayout1"))
        self.uiConsoleTextEdit = ConsoleView(self.uiConsoleDockWidgetContents)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.uiConsoleTextEdit.sizePolicy().hasHeightForWidth())
        self.uiConsoleTextEdit.setSizePolicy(sizePolicy)
        self.uiConsoleTextEdit.setObjectName(_fromUtf8("uiConsoleTextEdit"))
        self.vboxlayout1.addWidget(self.uiConsoleTextEdit)
        self.uiConsoleDockWidget.setWidget(self.uiConsoleDockWidgetContents)
        MainWindow.addDockWidget(QtCore.Qt.DockWidgetArea(8), self.uiConsoleDockWidget)
        self.uiAnnotationToolBar = QtGui.QToolBar(MainWindow)
        self.uiAnnotationToolBar.setIconSize(QtCore.QSize(32, 32))
        self.uiAnnotationToolBar.setObjectName(_fromUtf8("uiAnnotationToolBar"))
        MainWindow.addToolBar(QtCore.Qt.TopToolBarArea, self.uiAnnotationToolBar)
        self.uiTopologySummaryDockWidget = QtGui.QDockWidget(MainWindow)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Preferred, QtGui.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.uiTopologySummaryDockWidget.sizePolicy().hasHeightForWidth())
        self.uiTopologySummaryDockWidget.setSizePolicy(sizePolicy)
        self.uiTopologySummaryDockWidget.setAllowedAreas(QtCore.Qt.LeftDockWidgetArea|QtCore.Qt.RightDockWidgetArea)
        self.uiTopologySummaryDockWidget.setObjectName(_fromUtf8("uiTopologySummaryDockWidget"))
        self.uiTopologySummaryDockWidgetContents = QtGui.QWidget()
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Preferred, QtGui.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.uiTopologySummaryDockWidgetContents.sizePolicy().hasHeightForWidth())
        self.uiTopologySummaryDockWidgetContents.setSizePolicy(sizePolicy)
        self.uiTopologySummaryDockWidgetContents.setObjectName(_fromUtf8("uiTopologySummaryDockWidgetContents"))
        self.gridlayout1 = QtGui.QGridLayout(self.uiTopologySummaryDockWidgetContents)
        self.gridlayout1.setMargin(0)
        self.gridlayout1.setSpacing(0)
        self.gridlayout1.setObjectName(_fromUtf8("gridlayout1"))
        self.uiTopologySummaryTreeWidget = TopologySummaryView(self.uiTopologySummaryDockWidgetContents)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.uiTopologySummaryTreeWidget.sizePolicy().hasHeightForWidth())
        self.uiTopologySummaryTreeWidget.setSizePolicy(sizePolicy)
        self.uiTopologySummaryTreeWidget.setObjectName(_fromUtf8("uiTopologySummaryTreeWidget"))
        self.uiTopologySummaryTreeWidget.header().setVisible(False)
        self.gridlayout1.addWidget(self.uiTopologySummaryTreeWidget, 0, 0, 1, 1)
        self.uiTopologySummaryDockWidget.setWidget(self.uiTopologySummaryDockWidgetContents)
        MainWindow.addDockWidget(QtCore.Qt.DockWidgetArea(2), self.uiTopologySummaryDockWidget)
        self.uiCloudInspectorDockWidget = QtGui.QDockWidget(MainWindow)
        self.uiCloudInspectorDockWidget.setEnabled(True)
        self.uiCloudInspectorDockWidget.setObjectName(_fromUtf8("uiCloudInspectorDockWidget"))
        self.uiCloudInspectorDockWidgetContents = QtGui.QWidget()
        self.uiCloudInspectorDockWidgetContents.setObjectName(_fromUtf8("uiCloudInspectorDockWidgetContents"))
        self.verticalLayout = QtGui.QVBoxLayout(self.uiCloudInspectorDockWidgetContents)
        self.verticalLayout.setMargin(0)
        self.verticalLayout.setObjectName(_fromUtf8("verticalLayout"))
        self.CloudInspectorView = CloudInspectorView(self.uiCloudInspectorDockWidgetContents)
        self.CloudInspectorView.setAutoFillBackground(False)
        self.CloudInspectorView.setObjectName(_fromUtf8("CloudInspectorView"))
        self.verticalLayout.addWidget(self.CloudInspectorView)
        self.uiCloudInspectorDockWidget.setWidget(self.uiCloudInspectorDockWidgetContents)
        MainWindow.addDockWidget(QtCore.Qt.DockWidgetArea(2), self.uiCloudInspectorDockWidget)
        self.uiAboutAction = QtGui.QAction(MainWindow)
        self.uiAboutAction.setMenuRole(QtGui.QAction.AboutRole)
        self.uiAboutAction.setObjectName(_fromUtf8("uiAboutAction"))
        self.uiQuitAction = QtGui.QAction(MainWindow)
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap(_fromUtf8(":/icons/quit.svg")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.uiQuitAction.setIcon(icon)
        self.uiQuitAction.setObjectName(_fromUtf8("uiQuitAction"))
        self.uiOpenProjectAction = QtGui.QAction(MainWindow)
        icon1 = QtGui.QIcon()
        icon1.addPixmap(QtGui.QPixmap(_fromUtf8(":/icons/open.svg")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.uiOpenProjectAction.setIcon(icon1)
        self.uiOpenProjectAction.setObjectName(_fromUtf8("uiOpenProjectAction"))
        self.uiSaveProjectAction = QtGui.QAction(MainWindow)
        icon2 = QtGui.QIcon()
        icon2.addPixmap(QtGui.QPixmap(_fromUtf8(":/icons/save.svg")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.uiSaveProjectAction.setIcon(icon2)
        self.uiSaveProjectAction.setObjectName(_fromUtf8("uiSaveProjectAction"))
        self.uiOnlineHelpAction = QtGui.QAction(MainWindow)
        icon3 = QtGui.QIcon()
        icon3.addPixmap(QtGui.QPixmap(_fromUtf8(":/icons/help.svg")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.uiOnlineHelpAction.setIcon(icon3)
        self.uiOnlineHelpAction.setObjectName(_fromUtf8("uiOnlineHelpAction"))
        self.uiScreenshotAction = QtGui.QAction(MainWindow)
        icon4 = QtGui.QIcon()
        icon4.addPixmap(QtGui.QPixmap(_fromUtf8(":/icons/camera-photo.svg")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        icon4.addPixmap(QtGui.QPixmap(_fromUtf8(":/icons/camera-photo-hover.svg")), QtGui.QIcon.Active, QtGui.QIcon.Off)
        self.uiScreenshotAction.setIcon(icon4)
        self.uiScreenshotAction.setObjectName(_fromUtf8("uiScreenshotAction"))
        self.uiStartAllAction = QtGui.QAction(MainWindow)
        self.uiStartAllAction.setEnabled(True)
        icon5 = QtGui.QIcon()
        icon5.addPixmap(QtGui.QPixmap(_fromUtf8(":/icons/start.svg")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        icon5.addPixmap(QtGui.QPixmap(_fromUtf8(":/icons/start-hover.svg")), QtGui.QIcon.Active, QtGui.QIcon.Off)
        self.uiStartAllAction.setIcon(icon5)
        self.uiStartAllAction.setObjectName(_fromUtf8("uiStartAllAction"))
        self.uiStopAllAction = QtGui.QAction(MainWindow)
        self.uiStopAllAction.setEnabled(True)
        icon6 = QtGui.QIcon()
        icon6.addPixmap(QtGui.QPixmap(_fromUtf8(":/icons/stop.svg")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        icon6.addPixmap(QtGui.QPixmap(_fromUtf8(":/icons/stop-hover.svg")), QtGui.QIcon.Active, QtGui.QIcon.Off)
        self.uiStopAllAction.setIcon(icon6)
        self.uiStopAllAction.setObjectName(_fromUtf8("uiStopAllAction"))
        self.uiShowNamesAction = QtGui.QAction(MainWindow)
        self.uiShowNamesAction.setCheckable(True)
        icon7 = QtGui.QIcon()
        icon7.addPixmap(QtGui.QPixmap(_fromUtf8(":/icons/show-hostname.svg")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.uiShowNamesAction.setIcon(icon7)
        self.uiShowNamesAction.setObjectName(_fromUtf8("uiShowNamesAction"))
        self.uiConsoleAllAction = QtGui.QAction(MainWindow)
        self.uiConsoleAllAction.setEnabled(True)
        icon8 = QtGui.QIcon()
        icon8.addPixmap(QtGui.QPixmap(_fromUtf8(":/icons/console.svg")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.uiConsoleAllAction.setIcon(icon8)
        self.uiConsoleAllAction.setObjectName(_fromUtf8("uiConsoleAllAction"))
        self.uiAboutQtAction = QtGui.QAction(MainWindow)
        self.uiAboutQtAction.setMenuRole(QtGui.QAction.AboutQtRole)
        self.uiAboutQtAction.setObjectName(_fromUtf8("uiAboutQtAction"))
        self.uiZoomInAction = QtGui.QAction(MainWindow)
        icon9 = QtGui.QIcon()
        icon9.addPixmap(QtGui.QPixmap(_fromUtf8(":/icons/zoom-in.png")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        icon9.addPixmap(QtGui.QPixmap(_fromUtf8(":/icons/zoom-in-hover.png")), QtGui.QIcon.Active, QtGui.QIcon.Off)
        self.uiZoomInAction.setIcon(icon9)
        self.uiZoomInAction.setObjectName(_fromUtf8("uiZoomInAction"))
        self.uiZoomOutAction = QtGui.QAction(MainWindow)
        icon10 = QtGui.QIcon()
        icon10.addPixmap(QtGui.QPixmap(_fromUtf8(":/icons/zoom-out.png")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        icon10.addPixmap(QtGui.QPixmap(_fromUtf8(":/icons/zoom-out-hover.png")), QtGui.QIcon.Active, QtGui.QIcon.Off)
        self.uiZoomOutAction.setIcon(icon10)
        self.uiZoomOutAction.setObjectName(_fromUtf8("uiZoomOutAction"))
        self.uiZoomResetAction = QtGui.QAction(MainWindow)
        self.uiZoomResetAction.setObjectName(_fromUtf8("uiZoomResetAction"))
        self.uiSelectAllAction = QtGui.QAction(MainWindow)
        self.uiSelectAllAction.setObjectName(_fromUtf8("uiSelectAllAction"))
        self.uiSelectNoneAction = QtGui.QAction(MainWindow)
        self.uiSelectNoneAction.setObjectName(_fromUtf8("uiSelectNoneAction"))
        self.uiPreferencesAction = QtGui.QAction(MainWindow)
        icon11 = QtGui.QIcon()
        icon11.addPixmap(QtGui.QPixmap(_fromUtf8(":/icons/applications.svg")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.uiPreferencesAction.setIcon(icon11)
        self.uiPreferencesAction.setObjectName(_fromUtf8("uiPreferencesAction"))
        self.uiSuspendAllAction = QtGui.QAction(MainWindow)
        icon12 = QtGui.QIcon()
        icon12.addPixmap(QtGui.QPixmap(_fromUtf8(":/icons/pause.svg")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        icon12.addPixmap(QtGui.QPixmap(_fromUtf8(":/icons/pause-hover.svg")), QtGui.QIcon.Active, QtGui.QIcon.Off)
        self.uiSuspendAllAction.setIcon(icon12)
        self.uiSuspendAllAction.setObjectName(_fromUtf8("uiSuspendAllAction"))
        self.uiAddNoteAction = QtGui.QAction(MainWindow)
        self.uiAddNoteAction.setCheckable(True)
        icon13 = QtGui.QIcon()
        icon13.addPixmap(QtGui.QPixmap(_fromUtf8(":/icons/add-note.svg")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.uiAddNoteAction.setIcon(icon13)
        self.uiAddNoteAction.setObjectName(_fromUtf8("uiAddNoteAction"))
        self.uiNewProjectAction = QtGui.QAction(MainWindow)
        icon14 = QtGui.QIcon()
        icon14.addPixmap(QtGui.QPixmap(_fromUtf8(":/icons/new-project.svg")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.uiNewProjectAction.setIcon(icon14)
        self.uiNewProjectAction.setObjectName(_fromUtf8("uiNewProjectAction"))
        self.uiImportExportConfigsAction = QtGui.QAction(MainWindow)
        icon15 = QtGui.QIcon()
        icon15.addPixmap(QtGui.QPixmap(_fromUtf8(":/icons/import_export_configs.svg")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.uiImportExportConfigsAction.setIcon(icon15)
        self.uiImportExportConfigsAction.setObjectName(_fromUtf8("uiImportExportConfigsAction"))
        self.uiInsertImageAction = QtGui.QAction(MainWindow)
        self.uiInsertImageAction.setCheckable(False)
        icon16 = QtGui.QIcon()
        icon16.addPixmap(QtGui.QPixmap(_fromUtf8(":/icons/image.svg")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.uiInsertImageAction.setIcon(icon16)
        self.uiInsertImageAction.setObjectName(_fromUtf8("uiInsertImageAction"))
        self.uiDrawRectangleAction = QtGui.QAction(MainWindow)
        self.uiDrawRectangleAction.setCheckable(True)
        icon17 = QtGui.QIcon()
        icon17.addPixmap(QtGui.QPixmap(_fromUtf8(":/icons/rectangle.svg")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        icon17.addPixmap(QtGui.QPixmap(_fromUtf8(":/icons/rectangle-hover.svg")), QtGui.QIcon.Active, QtGui.QIcon.Off)
        self.uiDrawRectangleAction.setIcon(icon17)
        self.uiDrawRectangleAction.setObjectName(_fromUtf8("uiDrawRectangleAction"))
        self.uiDrawEllipseAction = QtGui.QAction(MainWindow)
        self.uiDrawEllipseAction.setCheckable(True)
        icon18 = QtGui.QIcon()
        icon18.addPixmap(QtGui.QPixmap(_fromUtf8(":/icons/ellipse.svg")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        icon18.addPixmap(QtGui.QPixmap(_fromUtf8(":/icons/ellipse-hover.svg")), QtGui.QIcon.Active, QtGui.QIcon.Off)
        self.uiDrawEllipseAction.setIcon(icon18)
        self.uiDrawEllipseAction.setObjectName(_fromUtf8("uiDrawEllipseAction"))
        self.uiShowPortNamesAction = QtGui.QAction(MainWindow)
        self.uiShowPortNamesAction.setCheckable(True)
        icon19 = QtGui.QIcon()
        icon19.addPixmap(QtGui.QPixmap(_fromUtf8(":/icons/show-interface-names.svg")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.uiShowPortNamesAction.setIcon(icon19)
        self.uiShowPortNamesAction.setObjectName(_fromUtf8("uiShowPortNamesAction"))
        self.uiSnapshotAction = QtGui.QAction(MainWindow)
        icon20 = QtGui.QIcon()
        icon20.addPixmap(QtGui.QPixmap(_fromUtf8(":/icons/snapshot.svg")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.uiSnapshotAction.setIcon(icon20)
        self.uiSnapshotAction.setObjectName(_fromUtf8("uiSnapshotAction"))
        self.uiShowLayersAction = QtGui.QAction(MainWindow)
        self.uiShowLayersAction.setCheckable(True)
        self.uiShowLayersAction.setObjectName(_fromUtf8("uiShowLayersAction"))
        self.uiSaveProjectAsAction = QtGui.QAction(MainWindow)
        icon21 = QtGui.QIcon()
        icon21.addPixmap(QtGui.QPixmap(_fromUtf8(":/icons/save-as-project.svg")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.uiSaveProjectAsAction.setIcon(icon21)
        self.uiSaveProjectAsAction.setObjectName(_fromUtf8("uiSaveProjectAsAction"))
        self.uiReloadAllAction = QtGui.QAction(MainWindow)
        icon22 = QtGui.QIcon()
        icon22.addPixmap(QtGui.QPixmap(_fromUtf8(":/icons/reload.svg")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.uiReloadAllAction.setIcon(icon22)
        self.uiReloadAllAction.setObjectName(_fromUtf8("uiReloadAllAction"))
        self.uiAuxConsoleAllAction = QtGui.QAction(MainWindow)
        self.uiAuxConsoleAllAction.setEnabled(True)
        icon23 = QtGui.QIcon()
        icon23.addPixmap(QtGui.QPixmap(_fromUtf8(":/icons/aux-console.svg")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.uiAuxConsoleAllAction.setIcon(icon23)
        self.uiAuxConsoleAllAction.setObjectName(_fromUtf8("uiAuxConsoleAllAction"))
        self.uiResetPortLabelsAction = QtGui.QAction(MainWindow)
        self.uiResetPortLabelsAction.setObjectName(_fromUtf8("uiResetPortLabelsAction"))
        self.uiCheckForUpdateAction = QtGui.QAction(MainWindow)
        self.uiCheckForUpdateAction.setObjectName(_fromUtf8("uiCheckForUpdateAction"))
        self.uiEnergySavingStyleAction = QtGui.QAction(MainWindow)
        self.uiEnergySavingStyleAction.setCheckable(True)
        self.uiEnergySavingStyleAction.setObjectName(_fromUtf8("uiEnergySavingStyleAction"))
        self.uiDefaultStyleAction = QtGui.QAction(MainWindow)
        self.uiDefaultStyleAction.setCheckable(True)
        self.uiDefaultStyleAction.setChecked(True)
        self.uiDefaultStyleAction.setObjectName(_fromUtf8("uiDefaultStyleAction"))
        self.uiBrowseRoutersAction = QtGui.QAction(MainWindow)
        icon24 = QtGui.QIcon()
        icon24.addPixmap(QtGui.QPixmap(_fromUtf8(":/icons/router.png")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        icon24.addPixmap(QtGui.QPixmap(_fromUtf8(":/icons/router-hover.png")), QtGui.QIcon.Active, QtGui.QIcon.Off)
        self.uiBrowseRoutersAction.setIcon(icon24)
        self.uiBrowseRoutersAction.setObjectName(_fromUtf8("uiBrowseRoutersAction"))
        self.uiBrowseSwitchesAction = QtGui.QAction(MainWindow)
        icon25 = QtGui.QIcon()
        icon25.addPixmap(QtGui.QPixmap(_fromUtf8(":/icons/switch.png")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        icon25.addPixmap(QtGui.QPixmap(_fromUtf8(":/icons/switch-hover.png")), QtGui.QIcon.Active, QtGui.QIcon.Off)
        self.uiBrowseSwitchesAction.setIcon(icon25)
        self.uiBrowseSwitchesAction.setObjectName(_fromUtf8("uiBrowseSwitchesAction"))
        self.uiBrowseEndDevicesAction = QtGui.QAction(MainWindow)
        icon26 = QtGui.QIcon()
        icon26.addPixmap(QtGui.QPixmap(_fromUtf8(":/icons/PC.png")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        icon26.addPixmap(QtGui.QPixmap(_fromUtf8(":/icons/PC-hover.png")), QtGui.QIcon.Active, QtGui.QIcon.Off)
        self.uiBrowseEndDevicesAction.setIcon(icon26)
        self.uiBrowseEndDevicesAction.setObjectName(_fromUtf8("uiBrowseEndDevicesAction"))
        self.uiBrowseSecurityDevicesAction = QtGui.QAction(MainWindow)
        icon27 = QtGui.QIcon()
        icon27.addPixmap(QtGui.QPixmap(_fromUtf8(":/icons/firewall.png")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        icon27.addPixmap(QtGui.QPixmap(_fromUtf8(":/icons/firewall-hover.png")), QtGui.QIcon.Active, QtGui.QIcon.Off)
        self.uiBrowseSecurityDevicesAction.setIcon(icon27)
        self.uiBrowseSecurityDevicesAction.setObjectName(_fromUtf8("uiBrowseSecurityDevicesAction"))
        self.uiBrowseAllDevicesAction = QtGui.QAction(MainWindow)
        icon28 = QtGui.QIcon()
        icon28.addPixmap(QtGui.QPixmap(_fromUtf8(":/icons/browse-all-icons.png")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        icon28.addPixmap(QtGui.QPixmap(_fromUtf8(":/icons/browse-all-icons-hover.png")), QtGui.QIcon.Active, QtGui.QIcon.Off)
        self.uiBrowseAllDevicesAction.setIcon(icon28)
        self.uiBrowseAllDevicesAction.setObjectName(_fromUtf8("uiBrowseAllDevicesAction"))
        self.uiAddLinkAction = QtGui.QAction(MainWindow)
        self.uiAddLinkAction.setCheckable(True)
        icon29 = QtGui.QIcon()
        icon29.addPixmap(QtGui.QPixmap(_fromUtf8(":/icons/connection-new.svg")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        icon29.addPixmap(QtGui.QPixmap(_fromUtf8(":/icons/cancel-connection.svg")), QtGui.QIcon.Normal, QtGui.QIcon.On)
        icon29.addPixmap(QtGui.QPixmap(_fromUtf8(":/icons/connection-new-hover.svg")), QtGui.QIcon.Active, QtGui.QIcon.Off)
        icon29.addPixmap(QtGui.QPixmap(_fromUtf8(":/icons/cancel-connection.svg")), QtGui.QIcon.Active, QtGui.QIcon.On)
        self.uiAddLinkAction.setIcon(icon29)
        self.uiAddLinkAction.setObjectName(_fromUtf8("uiAddLinkAction"))
        self.uiGettingStartedAction = QtGui.QAction(MainWindow)
        self.uiGettingStartedAction.setObjectName(_fromUtf8("uiGettingStartedAction"))
        self.uiLabInstructionsAction = QtGui.QAction(MainWindow)
        self.uiLabInstructionsAction.setObjectName(_fromUtf8("uiLabInstructionsAction"))
        self.uiFitInViewAction = QtGui.QAction(MainWindow)
        self.uiFitInViewAction.setObjectName(_fromUtf8("uiFitInViewAction"))
        self.uiExportProjectAction = QtGui.QAction(MainWindow)
        self.uiExportProjectAction.setVisible(False)
        self.uiExportProjectAction.setObjectName(_fromUtf8("uiExportProjectAction"))
        self.uiImportProjectAction = QtGui.QAction(MainWindow)
        self.uiImportProjectAction.setVisible(False)
        self.uiImportProjectAction.setObjectName(_fromUtf8("uiImportProjectAction"))
        self.uiMoveLocalProjectToCloudAction = QtGui.QAction(MainWindow)
        self.uiMoveLocalProjectToCloudAction.setVisible(False)
        self.uiMoveLocalProjectToCloudAction.setObjectName(_fromUtf8("uiMoveLocalProjectToCloudAction"))
        self.uiMoveCloudProjectToLocalAction = QtGui.QAction(MainWindow)
        self.uiMoveCloudProjectToLocalAction.setVisible(False)
        self.uiMoveCloudProjectToLocalAction.setObjectName(_fromUtf8("uiMoveCloudProjectToLocalAction"))
        self.uiDarkStyleAction = QtGui.QAction(MainWindow)
        self.uiDarkStyleAction.setObjectName(_fromUtf8("uiDarkStyleAction"))
        self.uiActionFullscreen = QtGui.QAction(MainWindow)
        self.uiActionFullscreen.setObjectName(_fromUtf8("uiActionFullscreen"))
        self.uiVPCSAction = QtGui.QAction(MainWindow)
        self.uiVPCSAction.setObjectName(_fromUtf8("uiVPCSAction"))
        self.uiEditMenu.addAction(self.uiSelectAllAction)
        self.uiEditMenu.addAction(self.uiSelectNoneAction)
        self.uiEditMenu.addSeparator()
        self.uiEditMenu.addAction(self.uiPreferencesAction)
        self.uiFileMenu.addAction(self.uiNewProjectAction)
        self.uiFileMenu.addAction(self.uiOpenProjectAction)
        self.uiFileMenu.addAction(self.uiSaveProjectAction)
        self.uiFileMenu.addAction(self.uiSaveProjectAsAction)
        self.uiFileMenu.addAction(self.uiExportProjectAction)
        self.uiFileMenu.addAction(self.uiImportProjectAction)
        self.uiFileMenu.addSeparator()
        self.uiFileMenu.addAction(self.uiMoveLocalProjectToCloudAction)
        self.uiFileMenu.addAction(self.uiMoveCloudProjectToLocalAction)
        self.uiFileMenu.addSeparator()
        self.uiFileMenu.addAction(self.uiImportExportConfigsAction)
        self.uiFileMenu.addAction(self.uiScreenshotAction)
        self.uiFileMenu.addAction(self.uiSnapshotAction)
        self.uiFileMenu.addSeparator()
        self.uiFileMenu.addAction(self.uiQuitAction)
        self.uiHelpMenu.addAction(self.uiOnlineHelpAction)
        self.uiHelpMenu.addAction(self.uiCheckForUpdateAction)
        self.uiHelpMenu.addAction(self.uiGettingStartedAction)
        self.uiHelpMenu.addAction(self.uiLabInstructionsAction)
        self.uiHelpMenu.addAction(self.uiAboutQtAction)
        self.uiHelpMenu.addAction(self.uiAboutAction)
        self.uiViewMenu.addAction(self.uiActionFullscreen)
        self.uiViewMenu.addSeparator()
        self.uiViewMenu.addAction(self.uiZoomInAction)
        self.uiViewMenu.addAction(self.uiZoomOutAction)
        self.uiViewMenu.addAction(self.uiZoomResetAction)
        self.uiViewMenu.addAction(self.uiFitInViewAction)
        self.uiViewMenu.addSeparator()
        self.uiViewMenu.addAction(self.uiShowLayersAction)
        self.uiViewMenu.addAction(self.uiResetPortLabelsAction)
        self.uiViewMenu.addAction(self.uiShowPortNamesAction)
        self.uiViewMenu.addSeparator()
        self.uiViewMenu.addAction(self.uiDocksMenu.menuAction())
        self.uiControlMenu.addAction(self.uiStartAllAction)
        self.uiControlMenu.addAction(self.uiSuspendAllAction)
        self.uiControlMenu.addAction(self.uiStopAllAction)
        self.uiControlMenu.addAction(self.uiReloadAllAction)
        self.uiControlMenu.addAction(self.uiAuxConsoleAllAction)
        self.uiControlMenu.addAction(self.uiConsoleAllAction)
        self.uiAnnotateMenu.addAction(self.uiAddNoteAction)
        self.uiAnnotateMenu.addAction(self.uiInsertImageAction)
        self.uiAnnotateMenu.addAction(self.uiDrawRectangleAction)
        self.uiAnnotateMenu.addAction(self.uiDrawEllipseAction)
        self.uiToolsMenu.addAction(self.uiVPCSAction)
        self.uiMenuBar.addAction(self.uiFileMenu.menuAction())
        self.uiMenuBar.addAction(self.uiEditMenu.menuAction())
        self.uiMenuBar.addAction(self.uiViewMenu.menuAction())
        self.uiMenuBar.addAction(self.uiControlMenu.menuAction())
        self.uiMenuBar.addAction(self.uiDeviceMenu.menuAction())
        self.uiMenuBar.addAction(self.uiAnnotateMenu.menuAction())
        self.uiMenuBar.addAction(self.uiToolsMenu.menuAction())
        self.uiMenuBar.addAction(self.uiHelpMenu.menuAction())
        self.uiGeneralToolBar.addAction(self.uiNewProjectAction)
        self.uiGeneralToolBar.addAction(self.uiOpenProjectAction)
        self.uiGeneralToolBar.addAction(self.uiSaveProjectAction)
        self.uiBrowsersToolBar.addAction(self.uiBrowseRoutersAction)
        self.uiBrowsersToolBar.addSeparator()
        self.uiBrowsersToolBar.addAction(self.uiBrowseSwitchesAction)
        self.uiBrowsersToolBar.addSeparator()
        self.uiBrowsersToolBar.addAction(self.uiBrowseEndDevicesAction)
        self.uiBrowsersToolBar.addSeparator()
        self.uiBrowsersToolBar.addAction(self.uiBrowseSecurityDevicesAction)
        self.uiBrowsersToolBar.addSeparator()
        self.uiBrowsersToolBar.addAction(self.uiBrowseAllDevicesAction)
        self.uiBrowsersToolBar.addSeparator()
        self.uiBrowsersToolBar.addAction(self.uiAddLinkAction)
        self.uiBrowsersToolBar.addSeparator()
        self.uiControlToolBar.addAction(self.uiSnapshotAction)
        self.uiControlToolBar.addAction(self.uiShowPortNamesAction)
        self.uiControlToolBar.addAction(self.uiConsoleAllAction)
        self.uiControlToolBar.addSeparator()
        self.uiControlToolBar.addAction(self.uiStartAllAction)
        self.uiControlToolBar.addAction(self.uiSuspendAllAction)
        self.uiControlToolBar.addAction(self.uiStopAllAction)
        self.uiControlToolBar.addAction(self.uiReloadAllAction)
        self.uiAnnotationToolBar.addAction(self.uiAddNoteAction)
        self.uiAnnotationToolBar.addAction(self.uiInsertImageAction)
        self.uiAnnotationToolBar.addAction(self.uiDrawRectangleAction)
        self.uiAnnotationToolBar.addAction(self.uiDrawEllipseAction)
        self.uiAnnotationToolBar.addAction(self.uiZoomInAction)
        self.uiAnnotationToolBar.addAction(self.uiZoomOutAction)
        self.uiAnnotationToolBar.addAction(self.uiScreenshotAction)

        self.retranslateUi(MainWindow)
        QtCore.QObject.connect(self.uiQuitAction, QtCore.SIGNAL(_fromUtf8("triggered()")), MainWindow.close)
        QtCore.QMetaObject.connectSlotsByName(MainWindow)
        MainWindow.setTabOrder(self.uiGraphicsView, self.uiNodesView)
        MainWindow.setTabOrder(self.uiNodesView, self.uiConsoleTextEdit)
        MainWindow.setTabOrder(self.uiConsoleTextEdit, self.uiTopologySummaryTreeWidget)

    def retranslateUi(self, MainWindow):
        self.uiEditMenu.setTitle(_translate("MainWindow", "&Edit", None))
        self.uiFileMenu.setTitle(_translate("MainWindow", "&File", None))
        self.uiHelpMenu.setTitle(_translate("MainWindow", "&Help", None))
        self.uiViewMenu.setTitle(_translate("MainWindow", "&View", None))
        self.uiDocksMenu.setTitle(_translate("MainWindow", "Docks", None))
        self.uiControlMenu.setTitle(_translate("MainWindow", "Control", None))
        self.uiAnnotateMenu.setTitle(_translate("MainWindow", "Annotate", None))
        self.uiDeviceMenu.setTitle(_translate("MainWindow", "Device", None))
        self.uiToolsMenu.setTitle(_translate("MainWindow", "&Tools", None))
        self.uiGeneralToolBar.setWindowTitle(_translate("MainWindow", "General", None))
        self.uiNodesDockWidget.setWindowTitle(_translate("MainWindow", "Node Types", None))
        self.uiNodesView.setToolTip(_translate("MainWindow", "Drag a node to the workspace (Press SHIFT while dragging to add multiple identical nodes).", None))
        self.uiNodesView.headerItem().setText(0, _translate("MainWindow", "1", None))
        self.uiBrowsersToolBar.setWindowTitle(_translate("MainWindow", "Devices", None))
        self.uiControlToolBar.setWindowTitle(_translate("MainWindow", "Emulation", None))
        self.uiConsoleDockWidget.setWindowTitle(_translate("MainWindow", "Console", None))
        self.uiAnnotationToolBar.setWindowTitle(_translate("MainWindow", "Drawing", None))
        self.uiTopologySummaryDockWidget.setWindowTitle(_translate("MainWindow", "Topology Summary", None))
        self.uiTopologySummaryTreeWidget.headerItem().setText(0, _translate("MainWindow", "1", None))
        self.uiCloudInspectorDockWidget.setWindowTitle(_translate("MainWindow", "Cloud Inspector", None))
        self.uiAboutAction.setText(_translate("MainWindow", "&About", None))
        self.uiAboutAction.setStatusTip(_translate("MainWindow", "About", None))
        self.uiQuitAction.setText(_translate("MainWindow", "&Quit", None))
        self.uiQuitAction.setStatusTip(_translate("MainWindow", "Quit", None))
        self.uiQuitAction.setShortcut(_translate("MainWindow", "Ctrl+Q", None))
        self.uiOpenProjectAction.setText(_translate("MainWindow", "&Open Project", None))
        self.uiOpenProjectAction.setToolTip(_translate("MainWindow", "Open project", None))
        self.uiOpenProjectAction.setStatusTip(_translate("MainWindow", "Open project", None))
        self.uiOpenProjectAction.setShortcut(_translate("MainWindow", "Ctrl+O", None))
        self.uiSaveProjectAction.setText(_translate("MainWindow", "&Save project", None))
        self.uiSaveProjectAction.setToolTip(_translate("MainWindow", "Save project", None))
        self.uiSaveProjectAction.setStatusTip(_translate("MainWindow", "Save project", None))
        self.uiSaveProjectAction.setShortcut(_translate("MainWindow", "Ctrl+S", None))
        self.uiOnlineHelpAction.setText(_translate("MainWindow", "&Online help", None))
        self.uiOnlineHelpAction.setToolTip(_translate("MainWindow", "Online help", None))
        self.uiOnlineHelpAction.setStatusTip(_translate("MainWindow", "Online Help", None))
        self.uiScreenshotAction.setText(_translate("MainWindow", "Take a screenshot", None))
        self.uiScreenshotAction.setToolTip(_translate("MainWindow", "Take a screenshot", None))
        self.uiScreenshotAction.setStatusTip(_translate("MainWindow", "Take a screenshot", None))
        self.uiStartAllAction.setText(_translate("MainWindow", "Start/Resume all devices", None))
        self.uiStartAllAction.setToolTip(_translate("MainWindow", "Start/Resume all devices", None))
        self.uiStartAllAction.setStatusTip(_translate("MainWindow", "Start/Resume all devices", None))
        self.uiStopAllAction.setText(_translate("MainWindow", "Stop all devices", None))
        self.uiStopAllAction.setToolTip(_translate("MainWindow", "Stop all devices", None))
        self.uiStopAllAction.setStatusTip(_translate("MainWindow", "Stop all devices", None))
        self.uiShowNamesAction.setText(_translate("MainWindow", "Show hostnames", None))
        self.uiShowNamesAction.setToolTip(_translate("MainWindow", "Show hostnames", None))
        self.uiShowNamesAction.setStatusTip(_translate("MainWindow", "Show hostnames", None))
        self.uiConsoleAllAction.setText(_translate("MainWindow", "Console connect to all devices", None))
        self.uiConsoleAllAction.setToolTip(_translate("MainWindow", "Console connect to all devices", None))
        self.uiConsoleAllAction.setStatusTip(_translate("MainWindow", "Console to all devices", None))
        self.uiAboutQtAction.setText(_translate("MainWindow", "About &Qt", None))
        self.uiAboutQtAction.setStatusTip(_translate("MainWindow", "About Qt", None))
        self.uiZoomInAction.setText(_translate("MainWindow", "Zoom in", None))
        self.uiZoomInAction.setToolTip(_translate("MainWindow", "Zoom in", None))
        self.uiZoomInAction.setStatusTip(_translate("MainWindow", "Zoom in", None))
        self.uiZoomInAction.setShortcut(_translate("MainWindow", "Ctrl++", None))
        self.uiZoomOutAction.setText(_translate("MainWindow", "Zoom out", None))
        self.uiZoomOutAction.setToolTip(_translate("MainWindow", "Zoom out", None))
        self.uiZoomOutAction.setStatusTip(_translate("MainWindow", "Zoom out", None))
        self.uiZoomOutAction.setShortcut(_translate("MainWindow", "Ctrl+-", None))
        self.uiZoomResetAction.setText(_translate("MainWindow", "Zoom reset", None))
        self.uiZoomResetAction.setStatusTip(_translate("MainWindow", "Zoom reset", None))
        self.uiZoomResetAction.setShortcut(_translate("MainWindow", "Ctrl+0", None))
        self.uiSelectAllAction.setText(_translate("MainWindow", "Select &all", None))
        self.uiSelectAllAction.setStatusTip(_translate("MainWindow", "Select All", None))
        self.uiSelectAllAction.setShortcut(_translate("MainWindow", "Ctrl+A", None))
        self.uiSelectNoneAction.setText(_translate("MainWindow", "Select &none", None))
        self.uiSelectNoneAction.setStatusTip(_translate("MainWindow", "Select None", None))
        self.uiSelectNoneAction.setShortcut(_translate("MainWindow", "Ctrl+Shift+A", None))
        self.uiPreferencesAction.setText(_translate("MainWindow", "&Preferences...", None))
        self.uiPreferencesAction.setStatusTip(_translate("MainWindow", "Preferences", None))
        self.uiPreferencesAction.setShortcut(_translate("MainWindow", "Ctrl+Shift+P", None))
        self.uiSuspendAllAction.setText(_translate("MainWindow", "Suspend all devices", None))
        self.uiSuspendAllAction.setToolTip(_translate("MainWindow", "Suspend all devices", None))
        self.uiSuspendAllAction.setStatusTip(_translate("MainWindow", "Suspend all devices", None))
        self.uiAddNoteAction.setText(_translate("MainWindow", "Add note", None))
        self.uiAddNoteAction.setToolTip(_translate("MainWindow", "Add a note", None))
        self.uiAddNoteAction.setStatusTip(_translate("MainWindow", "Add a note", None))
        self.uiNewProjectAction.setText(_translate("MainWindow", "&New blank project", None))
        self.uiNewProjectAction.setIconText(_translate("MainWindow", "New Project", None))
        self.uiNewProjectAction.setToolTip(_translate("MainWindow", "New blank project", None))
        self.uiNewProjectAction.setStatusTip(_translate("MainWindow", "New blank project", None))
        self.uiNewProjectAction.setShortcut(_translate("MainWindow", "Ctrl+N", None))
        self.uiImportExportConfigsAction.setText(_translate("MainWindow", "&Import/Export device configs", None))
        self.uiImportExportConfigsAction.setToolTip(_translate("MainWindow", "Import/Export device configs", None))
        self.uiImportExportConfigsAction.setStatusTip(_translate("MainWindow", "Import/Export device configs", None))
        self.uiInsertImageAction.setText(_translate("MainWindow", "Insert picture", None))
        self.uiInsertImageAction.setToolTip(_translate("MainWindow", "Insert a picture", None))
        self.uiInsertImageAction.setStatusTip(_translate("MainWindow", "Insert a picture", None))
        self.uiDrawRectangleAction.setText(_translate("MainWindow", "Draw rectangle", None))
        self.uiDrawRectangleAction.setToolTip(_translate("MainWindow", "Draw a rectangle", None))
        self.uiDrawRectangleAction.setStatusTip(_translate("MainWindow", "Draw a rectangle", None))
        self.uiDrawEllipseAction.setText(_translate("MainWindow", "Draw ellipse", None))
        self.uiDrawEllipseAction.setToolTip(_translate("MainWindow", "Draw an ellipse", None))
        self.uiDrawEllipseAction.setStatusTip(_translate("MainWindow", "Draw an ellipse", None))
        self.uiShowPortNamesAction.setText(_translate("MainWindow", "Show/Hide interface labels", None))
        self.uiShowPortNamesAction.setToolTip(_translate("MainWindow", "Show/Hide interface labels", None))
        self.uiShowPortNamesAction.setStatusTip(_translate("MainWindow", "Show/Hide interface labels", None))
        self.uiSnapshotAction.setText(_translate("MainWindow", "Manage snapshots", None))
        self.uiSnapshotAction.setToolTip(_translate("MainWindow", "Manage snapshots", None))
        self.uiSnapshotAction.setStatusTip(_translate("MainWindow", "Manage snapshots", None))
        self.uiShowLayersAction.setText(_translate("MainWindow", "Show layers", None))
        self.uiShowLayersAction.setStatusTip(_translate("MainWindow", "Show layers", None))
        self.uiSaveProjectAsAction.setText(_translate("MainWindow", "&Save project as…", None))
        self.uiSaveProjectAsAction.setToolTip(_translate("MainWindow", "Save project as...", None))
        self.uiSaveProjectAsAction.setStatusTip(_translate("MainWindow", "Save project as...", None))
        self.uiReloadAllAction.setText(_translate("MainWindow", "Reload all devices", None))
        self.uiReloadAllAction.setToolTip(_translate("MainWindow", "Reload all devices", None))
        self.uiReloadAllAction.setStatusTip(_translate("MainWindow", "Reload all devices", None))
        self.uiAuxConsoleAllAction.setText(_translate("MainWindow", "Console connect via AUX to all devices", None))
        self.uiAuxConsoleAllAction.setToolTip(_translate("MainWindow", "Console connect via AUX to all devices", None))
        self.uiAuxConsoleAllAction.setStatusTip(_translate("MainWindow", "Console AUX to all devices", None))
        self.uiResetPortLabelsAction.setText(_translate("MainWindow", "Reset interface labels", None))
        self.uiResetPortLabelsAction.setToolTip(_translate("MainWindow", "Reset interface labels", None))
        self.uiResetPortLabelsAction.setStatusTip(_translate("MainWindow", "Reset Interface Labels", None))
        self.uiCheckForUpdateAction.setText(_translate("MainWindow", "Check for Update", None))
        self.uiCheckForUpdateAction.setStatusTip(_translate("MainWindow", "Check for Update", None))
        self.uiEnergySavingStyleAction.setText(_translate("MainWindow", "Energy Saving", None))
        self.uiEnergySavingStyleAction.setStatusTip(_translate("MainWindow", "Energy Saving Mode", None))
        self.uiDefaultStyleAction.setText(_translate("MainWindow", "Default", None))
        self.uiBrowseRoutersAction.setText(_translate("MainWindow", "Browse Routers", None))
        self.uiBrowseRoutersAction.setIconText(_translate("MainWindow", "Browse Routers", None))
        self.uiBrowseRoutersAction.setToolTip(_translate("MainWindow", "Browse Routers", None))
        self.uiBrowseRoutersAction.setStatusTip(_translate("MainWindow", "Browse Routers", None))
        self.uiBrowseSwitchesAction.setText(_translate("MainWindow", "Browse Switches", None))
        self.uiBrowseSwitchesAction.setIconText(_translate("MainWindow", "Browse Switches", None))
        self.uiBrowseSwitchesAction.setToolTip(_translate("MainWindow", "Browse Switches", None))
        self.uiBrowseSwitchesAction.setStatusTip(_translate("MainWindow", "Browse Switches", None))
        self.uiBrowseEndDevicesAction.setText(_translate("MainWindow", "Browse End Devices", None))
        self.uiBrowseEndDevicesAction.setIconText(_translate("MainWindow", "Browse End Devices", None))
        self.uiBrowseEndDevicesAction.setToolTip(_translate("MainWindow", "Browse End Devices", None))
        self.uiBrowseEndDevicesAction.setStatusTip(_translate("MainWindow", "Browse End Devices", None))
        self.uiBrowseSecurityDevicesAction.setText(_translate("MainWindow", "Browse Security Devices", None))
        self.uiBrowseSecurityDevicesAction.setIconText(_translate("MainWindow", "Browse Security Devices", None))
        self.uiBrowseSecurityDevicesAction.setToolTip(_translate("MainWindow", "Browse Security Devices", None))
        self.uiBrowseSecurityDevicesAction.setStatusTip(_translate("MainWindow", "Browse Security Devices", None))
        self.uiBrowseAllDevicesAction.setText(_translate("MainWindow", "Browse all devices", None))
        self.uiBrowseAllDevicesAction.setToolTip(_translate("MainWindow", "Browse all devices", None))
        self.uiBrowseAllDevicesAction.setStatusTip(_translate("MainWindow", "Browse all devices", None))
        self.uiAddLinkAction.setText(_translate("MainWindow", "Add a link", None))
        self.uiAddLinkAction.setToolTip(_translate("MainWindow", "Add a link", None))
        self.uiAddLinkAction.setStatusTip(_translate("MainWindow", "Add a link", None))
        self.uiGettingStartedAction.setText(_translate("MainWindow", "Getting started", None))
        self.uiGettingStartedAction.setToolTip(_translate("MainWindow", "Show GNS3 news", None))
        self.uiLabInstructionsAction.setText(_translate("MainWindow", "Lab instructions", None))
        self.uiFitInViewAction.setText(_translate("MainWindow", "Fit in view", None))
        self.uiExportProjectAction.setText(_translate("MainWindow", "Backup project to cloud", None))
        self.uiImportProjectAction.setText(_translate("MainWindow", "Restore backup from cloud", None))
        self.uiMoveLocalProjectToCloudAction.setText(_translate("MainWindow", "Move local project to cloud", None))
        self.uiMoveCloudProjectToLocalAction.setText(_translate("MainWindow", "Move cloud project to local", None))
        self.uiDarkStyleAction.setText(_translate("MainWindow", "Dark Style", None))
        self.uiActionFullscreen.setText(_translate("MainWindow", "Fullscreen", None))
        self.uiActionFullscreen.setShortcut(_translate("MainWindow", "Ctrl+F", None))
        self.uiVPCSAction.setText(_translate("MainWindow", "&VPCS multi-host", None))

from ..cloud_inspector_view import CloudInspectorView
from ..console_view import ConsoleView
from ..nodes_view import NodesView
from ..graphics_view import GraphicsView
from ..topology_summary_view import TopologySummaryView
from . import resources_rc



# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file '/home/grossmj/PycharmProjects/gns3-gui/gns3/modules/dynamips/ui/ios_router_preferences_page.ui'
#
# Created: Wed Mar 11 22:03:56 2015
#      by: PyQt4 UI code generator 4.10.4
#
# WARNING! All changes made in this file will be lost!

from PyQt4 import QtCore, QtGui

try:
    _fromUtf8 = QtCore.QString.fromUtf8
except AttributeError:
    def _fromUtf8(s):
        return s

try:
    _encoding = QtGui.QApplication.UnicodeUTF8
    def _translate(context, text, disambig):
        return QtGui.QApplication.translate(context, text, disambig, _encoding)
except AttributeError:
    def _translate(context, text, disambig):
        return QtGui.QApplication.translate(context, text, disambig)

class Ui_IOSRouterPreferencesPageWidget(object):
    def setupUi(self, IOSRouterPreferencesPageWidget):
        IOSRouterPreferencesPageWidget.setObjectName(_fromUtf8("IOSRouterPreferencesPageWidget"))
        IOSRouterPreferencesPageWidget.resize(560, 518)
        self.gridLayout = QtGui.QGridLayout(IOSRouterPreferencesPageWidget)
        self.gridLayout.setObjectName(_fromUtf8("gridLayout"))
        self.uiIOSRoutersTreeWidget = QtGui.QTreeWidget(IOSRouterPreferencesPageWidget)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Minimum, QtGui.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.uiIOSRoutersTreeWidget.sizePolicy().hasHeightForWidth())
        self.uiIOSRoutersTreeWidget.setSizePolicy(sizePolicy)
        self.uiIOSRoutersTreeWidget.setMaximumSize(QtCore.QSize(160, 16777215))
        font = QtGui.QFont()
        font.setPointSize(11)
        font.setBold(True)
        font.setWeight(75)
        self.uiIOSRoutersTreeWidget.setFont(font)
        self.uiIOSRoutersTreeWidget.setIconSize(QtCore.QSize(32, 32))
        self.uiIOSRoutersTreeWidget.setRootIsDecorated(False)
        self.uiIOSRoutersTreeWidget.setObjectName(_fromUtf8("uiIOSRoutersTreeWidget"))
        self.uiIOSRoutersTreeWidget.headerItem().setText(0, _fromUtf8("1"))
        self.uiIOSRoutersTreeWidget.header().setVisible(False)
        self.gridLayout.addWidget(self.uiIOSRoutersTreeWidget, 0, 0, 2, 1)
        self.uiIOSRouterInfoTreeWidget = QtGui.QTreeWidget(IOSRouterPreferencesPageWidget)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.MinimumExpanding, QtGui.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.uiIOSRouterInfoTreeWidget.sizePolicy().hasHeightForWidth())
        self.uiIOSRouterInfoTreeWidget.setSizePolicy(sizePolicy)
        self.uiIOSRouterInfoTreeWidget.setIndentation(10)
        self.uiIOSRouterInfoTreeWidget.setAllColumnsShowFocus(True)
        self.uiIOSRouterInfoTreeWidget.setObjectName(_fromUtf8("uiIOSRouterInfoTreeWidget"))
        self.uiIOSRouterInfoTreeWidget.header().setVisible(False)
        self.gridLayout.addWidget(self.uiIOSRouterInfoTreeWidget, 0, 1, 1, 1)
        self.horizontalLayout_6 = QtGui.QHBoxLayout()
        self.horizontalLayout_6.setObjectName(_fromUtf8("horizontalLayout_6"))
        self.uiNewIOSRouterPushButton = QtGui.QPushButton(IOSRouterPreferencesPageWidget)
        self.uiNewIOSRouterPushButton.setObjectName(_fromUtf8("uiNewIOSRouterPushButton"))
        self.horizontalLayout_6.addWidget(self.uiNewIOSRouterPushButton)
        self.uiDecompressIOSPushButton = QtGui.QPushButton(IOSRouterPreferencesPageWidget)
        self.uiDecompressIOSPushButton.setEnabled(False)
        self.uiDecompressIOSPushButton.setObjectName(_fromUtf8("uiDecompressIOSPushButton"))
        self.horizontalLayout_6.addWidget(self.uiDecompressIOSPushButton)
        self.uiEditIOSRouterPushButton = QtGui.QPushButton(IOSRouterPreferencesPageWidget)
        self.uiEditIOSRouterPushButton.setEnabled(False)
        self.uiEditIOSRouterPushButton.setObjectName(_fromUtf8("uiEditIOSRouterPushButton"))
        self.horizontalLayout_6.addWidget(self.uiEditIOSRouterPushButton)
        self.uiDeleteIOSRouterPushButton = QtGui.QPushButton(IOSRouterPreferencesPageWidget)
        self.uiDeleteIOSRouterPushButton.setEnabled(False)
        self.uiDeleteIOSRouterPushButton.setObjectName(_fromUtf8("uiDeleteIOSRouterPushButton"))
        self.horizontalLayout_6.addWidget(self.uiDeleteIOSRouterPushButton)
        self.gridLayout.addLayout(self.horizontalLayout_6, 1, 1, 1, 1)

        self.retranslateUi(IOSRouterPreferencesPageWidget)
        QtCore.QMetaObject.connectSlotsByName(IOSRouterPreferencesPageWidget)

    def retranslateUi(self, IOSRouterPreferencesPageWidget):
        IOSRouterPreferencesPageWidget.setWindowTitle(_translate("IOSRouterPreferencesPageWidget", "IOS routers", None))
        IOSRouterPreferencesPageWidget.setAccessibleName(_translate("IOSRouterPreferencesPageWidget", "IOS router templates", None))
        self.uiIOSRouterInfoTreeWidget.headerItem().setText(0, _translate("IOSRouterPreferencesPageWidget", "1", None))
        self.uiIOSRouterInfoTreeWidget.headerItem().setText(1, _translate("IOSRouterPreferencesPageWidget", "2", None))
        self.uiNewIOSRouterPushButton.setText(_translate("IOSRouterPreferencesPageWidget", "&New", None))
        self.uiDecompressIOSPushButton.setText(_translate("IOSRouterPreferencesPageWidget", "&Decompress", None))
        self.uiEditIOSRouterPushButton.setText(_translate("IOSRouterPreferencesPageWidget", "&Edit", None))
        self.uiDeleteIOSRouterPushButton.setText(_translate("IOSRouterPreferencesPageWidget", "&Delete", None))




# -*- coding: utf-8 -*-
#
# Copyright (C) 2014 GNS3 Technologies Inc.
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

"""
Wizard for QEMU VMs.
"""

import sys

from gns3.qt import QtCore, QtGui
from gns3.servers import Servers
from gns3.node import Node
from gns3.modules.module_error import ModuleError
from gns3.settings import ENABLE_CLOUD

from .. import Qemu
from ..ui.qemu_vm_wizard_ui import Ui_QemuVMWizard
from ..pages.qemu_vm_configuration_page import QemuVMConfigurationPage
from ..settings import QEMU_BINARIES_FOR_CLOUD


class QemuVMWizard(QtGui.QWizard, Ui_QemuVMWizard):

    """
    Wizard to create a Qemu VM.

    :param parent: parent widget
    """

    def __init__(self, qemu_vms, parent):

        QtGui.QWizard.__init__(self, parent)
        self.setupUi(self)
        self.setPixmap(QtGui.QWizard.LogoPixmap, QtGui.QPixmap(":/icons/qemu.svg"))
        self.setWizardStyle(QtGui.QWizard.ModernStyle)
        if sys.platform.startswith("darwin"):
            # we want to see the cancel button on OSX
            self.setOptions(QtGui.QWizard.NoDefaultButton)

        self.uiRemoteRadioButton.toggled.connect(self._remoteServerToggledSlot)
        self.uiHdaDiskImageToolButton.clicked.connect(self._hdaDiskImageBrowserSlot)
        self.uiHdbDiskImageToolButton.clicked.connect(self._hdbDiskImageBrowserSlot)
        self.uiInitrdToolButton.clicked.connect(self._initrdBrowserSlot)
        self.uiKernelImageToolButton.clicked.connect(self._kernelImageBrowserSlot)
        self.uiTypeComboBox.currentIndexChanged[str].connect(self._typeChangedSlot)

        # Available types
        self.uiTypeComboBox.addItems(["Default", "IOSv", "IOSv-L2", "ASA 8.4(2)", "IDS"])

        # Mandatory fields
        self.uiNameWizardPage.registerField("vm_name*", self.uiNameLineEdit)
        self.uiDiskWizardPage.registerField("hda_disk_image*", self.uiHdaDiskImageLineEdit)
        self.uiDiskImageHdbWizardPage.registerField("hdb_disk_image*", self.uiHdbDiskImageLineEdit)
        self.uiASAWizardPage.registerField("initrd*", self.uiInitrdLineEdit)
        self.uiASAWizardPage.registerField("kernel_image*", self.uiKernelImageLineEdit)

        self._qemu_vms = qemu_vms

        if Qemu.instance().settings()["use_local_server"]:
            # skip the server page if we use the local server
            self.setStartId(1)

        # By default we use the local server
        self._server = Servers.instance().localServer()

        if not ENABLE_CLOUD:
            self.uiCloudRadioButton.hide()

    def _remoteServerToggledSlot(self, checked):
        """
        Slot for when the remote server radio button is toggled.

        :param checked: either the button is checked or not
        """

        if checked:
            self.uiRemoteServersGroupBox.setEnabled(True)
        else:
            self.uiRemoteServersGroupBox.setEnabled(False)

    def _typeChangedSlot(self, vm_type):
        """
        When the type of QEMU VM is changed.

        :param vm_type: type of VM
        """

        if vm_type == "IOSv":
            self.setPixmap(QtGui.QWizard.LogoPixmap, QtGui.QPixmap(":/symbols/iosv_virl.normal.svg"))
            self.uiNameLineEdit.setText("vIOS")
            self.uiHdaDiskImageLabel.setText("IOSv VDMK file:")
        elif vm_type == "IOSv-L2":
            self.setPixmap(QtGui.QWizard.LogoPixmap, QtGui.QPixmap(":/symbols/iosv_l2_virl.normal.svg"))
            self.uiNameLineEdit.setText("vIOS-L2")
            self.uiHdaDiskImageLabel.setText("IOSv-L2 VDMK file:")
        elif vm_type == "ASA 8.4(2)":
            self.setPixmap(QtGui.QWizard.LogoPixmap, QtGui.QPixmap(":/symbols/asa.normal.svg"))
            self.uiNameLineEdit.setText("ASA")
        elif vm_type == "IDS":
            self.setPixmap(QtGui.QWizard.LogoPixmap, QtGui.QPixmap(":/symbols/ids.normal.svg"))
            self.uiNameLineEdit.setText("IDS")
            self.uiHdaDiskImageLabel.setText("Disk image (hda):")
        else:
            self.setPixmap(QtGui.QWizard.LogoPixmap, QtGui.QPixmap(":/icons/qemu.svg"))
            self.uiHdaDiskImageLabel.setText("Disk image (hda):")
            self.uiNameLineEdit.setText("")

    def _hdaDiskImageBrowserSlot(self):
        """
        Slot to open a file browser and select a QEMU hda disk image.
        """

        path = QemuVMConfigurationPage.getDiskImage(self)
        if path:
            self.uiHdaDiskImageLineEdit.clear()
            self.uiHdaDiskImageLineEdit.setText(path)

    def _hdbDiskImageBrowserSlot(self):
        """
        Slot to open a file browser and select a QEMU hdb disk image.
        """

        path = QemuVMConfigurationPage.getDiskImage(self)
        if path:
            self.uiHdbDiskImageLineEdit.clear()
            self.uiHdbDiskImageLineEdit.setText(path)

    def _initrdBrowserSlot(self):
        """
        Slot to open a file browser and select a QEMU initrd.
        """

        path = QemuVMConfigurationPage.getDiskImage(self)
        if path:
            self.uiInitrdLineEdit.clear()
            self.uiInitrdLineEdit.setText(path)

    def _kernelImageBrowserSlot(self):
        """
        Slot to open a file browser and select a QEMU kernel image.
        """

        from ..pages.qemu_vm_configuration_page import QemuVMConfigurationPage
        path = QemuVMConfigurationPage.getDiskImage(self)
        if path:
            self.uiKernelImageLineEdit.clear()
            self.uiKernelImageLineEdit.setText(path)

    def validateCurrentPage(self):
        """
        Validates the server.
        """

        if self.currentPage() == self.uiServerWizardPage:
            if not self.uiCloudRadioButton.isChecked():
                if Qemu.instance().settings()["use_local_server"] or self.uiLocalRadioButton.isChecked():
                    server = Servers.instance().localServer()
                elif self.uiRemoteRadioButton.isChecked():
                    if not Servers.instance().remoteServers():
                        QtGui.QMessageBox.critical(self, "Remote server", "There is no remote server registered in QEMU preferences")
                        return False
                    server = self.uiRemoteServersComboBox.itemData(self.uiRemoteServersComboBox.currentIndex())
                self._server = server

        if self.currentPage() == self.uiNameWizardPage:
            name = self.uiNameLineEdit.text()
            for qemu_vm in self._qemu_vms.values():
                if qemu_vm["name"] == name:
                    QtGui.QMessageBox.critical(self, "Name", "{} is already used, please choose another name".format(name))
                    return False

        if self.currentPage() == self.uiBinaryMemoryWizardPage:
            if not self.uiQemuListComboBox.count():
                QtGui.QMessageBox.critical(self, "QEMU binaries", "Sorry, no QEMU binary has been found. Please make sure QEMU is installed before continuing")
                return False

        return True

    def initializePage(self, page_id):

        if self.page(page_id) == self.uiServerWizardPage:
            self.uiRemoteServersComboBox.clear()
            for server in Servers.instance().remoteServers().values():
                self.uiRemoteServersComboBox.addItem("{}:{}".format(server.host, server.port), server)
        if self.page(page_id) == self.uiBinaryMemoryWizardPage:
            if self.uiCloudRadioButton.isChecked():
                for binary in QEMU_BINARIES_FOR_CLOUD:
                    self.uiQemuListComboBox.addItem("{path}".format(path=binary), binary)
                # Default to x86_64 for the user
                index = self.uiQemuListComboBox.findData("x86_64", flags=QtCore.Qt.MatchEndsWith)
                if index != -1:
                    self.uiQemuListComboBox.setCurrentIndex(index)
            else:
                try:
                    Qemu.instance().getQemuBinariesFromServer(self._server, self._getQemuBinariesFromServerCallback)
                except ModuleError as e:
                    QtGui.QMessageBox.critical(self, "Qemu binaries", "Error while getting the QEMU binaries: {}".format(e))

    def _getQemuBinariesFromServerCallback(self, result, error=False, **kwargs):
        """
        Callback for getQemuBinariesFromServer.

        :param result: server response
        :param error: indicates an error (boolean)
        """

        if error:
            QtGui.QMessageBox.critical(self, "Qemu binaries", "{}".format(result["message"]))
        else:
            self.uiQemuListComboBox.clear()
            for qemu in result:
                if qemu["version"]:
                    self.uiQemuListComboBox.addItem("{path} (v{version})".format(path=qemu["path"], version=qemu["version"]), qemu["path"])
                else:
                    self.uiQemuListComboBox.addItem("{path}".format(path=qemu["path"]), qemu["path"])

            is_64bit = sys.maxsize > 2 ** 32
            if sys.platform.startswith("win"):
                if self.uiTypeComboBox.currentText() != "Default" and (Qemu.instance().settings()["use_local_server"] or self.uiLocalRadioButton.isChecked()):
                    search_string = r"qemu-0.13.0\qemu-system-i386w.exe"
                elif is_64bit:
                    # default is qemu-system-x86_64w.exe on Windows 64-bit with a remote server
                    search_string = "x86_64w.exe"
                else:
                    # default is qemu-system-i386w.exe on Windows 32-bit with a remote server
                    search_string = "i386w.exe"
            elif sys.platform.startswith("darwin") and hasattr(sys, "frozen") and (Qemu.instance().settings()["use_local_server"] or self.uiLocalRadioButton.isChecked()):
                search_string = "GNS3.app/Contents/Resources/qemu/bin/qemu-system-x86_64"
            elif is_64bit:
                # default is qemu-system-x86_64 on other 64-bit platforms
                search_string = "x86_64"
            else:
                # default is qemu-system-i386 on other platforms
                search_string = "i386"

            index = self.uiQemuListComboBox.findData(search_string, flags=QtCore.Qt.MatchEndsWith)
            if index != -1:
                self.uiQemuListComboBox.setCurrentIndex(index)

    def getSettings(self):
        """
        Returns the settings set in this Wizard.

        :return: settings dict
        """

        if Qemu.instance().settings()["use_local_server"] or self.uiLocalRadioButton.isChecked():
            server = "local"
        elif self.uiRemoteRadioButton.isChecked():
            server = self.uiRemoteServersComboBox.currentText()
        else:  # Cloud is selected
            server = "cloud"

        qemu_path = self.uiQemuListComboBox.itemData(self.uiQemuListComboBox.currentIndex())
        settings = {
            "name": self.uiNameLineEdit.text(),
            "ram": self.uiRamSpinBox.value(),
            "qemu_path": qemu_path,
            "server": server,
        }

        if self.uiTypeComboBox.currentText() == "IOSv":
            settings["adapters"] = 8
            settings["hda_disk_image"] = self.uiHdaDiskImageLineEdit.text()
            settings["default_symbol"] = ":/symbols/iosv_virl.normal.svg"
            settings["hover_symbol"] = ":/symbols/iosv_virl.selected.svg"
            settings["category"] = Node.routers
        elif self.uiTypeComboBox.currentText() == "IOSv-L2":
            settings["adapters"] = 8
            settings["hda_disk_image"] = self.uiHdaDiskImageLineEdit.text()
            settings["default_symbol"] = ":/symbols/iosv_l2_virl.normal.svg"
            settings["hover_symbol"] = ":/symbols/iosv_l2_virl.selected.svg"
            settings["category"] = Node.switches
        elif self.uiTypeComboBox.currentText() == "ASA 8.4(2)":
            settings["adapters"] = 4
            settings["initrd"] = self.uiInitrdLineEdit.text()
            settings["kernel_image"] = self.uiKernelImageLineEdit.text()
            settings["kernel_command_line"] = "ide_generic.probe_mask=0x01 ide_core.chs=0.0:980,16,32 auto nousb console=ttyS0,9600 bigphysarea=65536 ide1=noprobe no-hlt"
            settings["options"] = "-icount auto -hdachs 980,16,32"
            if not sys.platform.startswith("darwin"):
                settings["cpu_throttling"] = 80  # limit to 80% CPU usage
            settings["process_priority"] = "low"
            settings["default_symbol"] = ":/symbols/asa.normal.svg"
            settings["hover_symbol"] = ":/symbols/asa.selected.svg"
            settings["category"] = Node.security_devices
        elif self.uiTypeComboBox.currentText() == "IDS":
            settings["adapters"] = 3
            settings["hda_disk_image"] = self.uiHdaDiskImageLineEdit.text()
            settings["hdb_disk_image"] = self.uiHdbDiskImageLineEdit.text()
            settings["options"] = "-smbios type=1,product=IDS-4215"
            settings["default_symbol"] = ":/symbols/ids.normal.svg"
            settings["hover_symbol"] = ":/symbols/ids.selected.svg"
            settings["category"] = Node.security_devices
        else:
            settings["hda_disk_image"] = self.uiHdaDiskImageLineEdit.text()
            settings["category"] = Node.end_devices

        if "options" not in settings:
            settings["options"] = ""
        if server == "local" and (sys.platform.startswith("win") and qemu_path.endswith(r"qemu-0.13.0\qemu-system-i386w.exe")) or \
                (sys.platform.startswith("darwin") and "GNS3.app" in qemu_path):
            settings["options"] += " -vga none -vnc none"
            settings["legacy_networking"] = True
        else:
            settings["options"] += " -nographic"
        settings["options"] = settings["options"].strip()

        return settings

    def nextId(self):
        """
        Wizard rules!
        """

        current_id = self.currentId()
        if self.page(current_id) == self.uiTypeWizardPage:

            if self.uiTypeComboBox.currentText().startswith("IOSv"):
                self.uiRamSpinBox.setValue(384)
            elif self.uiTypeComboBox.currentText() != "Default":
                self.uiRamSpinBox.setValue(1024)

        elif self.page(current_id) == self.uiBinaryMemoryWizardPage:

            if self.uiTypeComboBox.currentText() == "ASA 8.4(2)":
                return self.uiBinaryMemoryWizardPage.nextId() + 1

        elif self.page(current_id) == self.uiDiskWizardPage:

            if self.uiTypeComboBox.currentText() == "IDS":
                return self.uiDiskWizardPage.nextId() + 1
            return -1

        elif self.page(current_id) == self.uiASAWizardPage:
            return -1

        return QtGui.QWizard.nextId(self)



# -*- coding: utf-8 -*-
#
# Copyright (C) 2014 GNS3 Technologies Inc.
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

"""
Functions to start external console terminals.
"""

from .qt import QtCore, QtGui

import sys
import shlex
import subprocess
from .main_window import MainWindow

import logging
log = logging.getLogger(__name__)


class ConsoleThread(QtCore.QThread):

    consoleDone = QtCore.pyqtSignal(str, str, int)

    def __init__(self, parent, command, name, host, port):
        super(QtCore.QThread, self).__init__(parent)
        self._command = command
        self._name = name
        self._host = host
        self._port = port

    def exec_command(self):

        if sys.platform.startswith("win"):
            # use the string on Windows
            subprocess.call(self._command)
        else:
            # use arguments on other platforms
            args = shlex.split(self._command)
            subprocess.call(args)

    def run(self):

        try:
            self.exec_command()
        except (OSError, subprocess.SubprocessError) as e:
            pass
            # log.warning('could not start Telnet console "{}": {}'.format(self._command, e))
        finally:
            # emit signal upon completion
            self.consoleDone.emit(self._name, self._host, self._port)


def telnetConsole(name, host, port, callback=None):
    """
    Start a Telnet console program.

    :param host: host or IP address
    :param port: port number
    """

    command = MainWindow.instance().telnetConsoleCommand()
    if not command:
        return

    # replace the place-holders by the actual values
    command = command.replace("%h", host)
    command = command.replace("%p", str(port))
    command = command.replace("%d", name)

    if callback is not None:
        log.info('starting telnet console in thread "{}"'.format(command))
        console_thread = ConsoleThread(MainWindow.instance(), command, name, host, port)
        console_thread.consoleDone.connect(callback)
        console_thread.start()
    else:
        try:
            log.info('starting telnet console "{}"'.format(command))
            if sys.platform.startswith("win"):
                # use the string on Windows
                subprocess.Popen(command)
            else:
                # use arguments on other platforms
                args = shlex.split(command)
                subprocess.Popen(args)
        except (OSError, ValueError, subprocess.SubprocessError) as e:
            log.warning('could not start Telnet console "{}": {}'.format(command, e))
            raise



# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file '/home/grossmj/workspace/git/gns3-gui/gns3/modules/dynamips/ui/atm_switch_configuration_page.ui'
#
# Created: Sun Mar 16 11:16:57 2014
#      by: PyQt4 UI code generator 4.10
#
# WARNING! All changes made in this file will be lost!

from PyQt4 import QtCore, QtGui

try:
    _fromUtf8 = QtCore.QString.fromUtf8
except AttributeError:
    def _fromUtf8(s):
        return s

try:
    _encoding = QtGui.QApplication.UnicodeUTF8

    def _translate(context, text, disambig):
        return QtGui.QApplication.translate(context, text, disambig, _encoding)
except AttributeError:
    def _translate(context, text, disambig):
        return QtGui.QApplication.translate(context, text, disambig)


class Ui_atmSwitchConfigPageWidget(object):

    def setupUi(self, atmSwitchConfigPageWidget):
        atmSwitchConfigPageWidget.setObjectName(_fromUtf8("atmSwitchConfigPageWidget"))
        atmSwitchConfigPageWidget.resize(459, 419)
        self.gridLayout_2 = QtGui.QGridLayout(atmSwitchConfigPageWidget)
        self.gridLayout_2.setObjectName(_fromUtf8("gridLayout_2"))
        self.uiGeneralGroupBox = QtGui.QGroupBox(atmSwitchConfigPageWidget)
        self.uiGeneralGroupBox.setObjectName(_fromUtf8("uiGeneralGroupBox"))
        self.gridLayout = QtGui.QGridLayout(self.uiGeneralGroupBox)
        self.gridLayout.setObjectName(_fromUtf8("gridLayout"))
        self.uiNameLabel = QtGui.QLabel(self.uiGeneralGroupBox)
        self.uiNameLabel.setObjectName(_fromUtf8("uiNameLabel"))
        self.gridLayout.addWidget(self.uiNameLabel, 0, 0, 1, 1)
        self.uiNameLineEdit = QtGui.QLineEdit(self.uiGeneralGroupBox)
        self.uiNameLineEdit.setObjectName(_fromUtf8("uiNameLineEdit"))
        self.gridLayout.addWidget(self.uiNameLineEdit, 0, 1, 1, 1)
        self.uiVPICheckBox = QtGui.QCheckBox(self.uiGeneralGroupBox)
        self.uiVPICheckBox.setObjectName(_fromUtf8("uiVPICheckBox"))
        self.gridLayout.addWidget(self.uiVPICheckBox, 1, 0, 1, 2)
        self.gridLayout_2.addWidget(self.uiGeneralGroupBox, 0, 0, 1, 3)
        self.uiMappingGroupBox = QtGui.QGroupBox(atmSwitchConfigPageWidget)
        self.uiMappingGroupBox.setObjectName(_fromUtf8("uiMappingGroupBox"))
        self.vboxlayout = QtGui.QVBoxLayout(self.uiMappingGroupBox)
        self.vboxlayout.setObjectName(_fromUtf8("vboxlayout"))
        self.uiMappingTreeWidget = QtGui.QTreeWidget(self.uiMappingGroupBox)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.uiMappingTreeWidget.sizePolicy().hasHeightForWidth())
        self.uiMappingTreeWidget.setSizePolicy(sizePolicy)
        self.uiMappingTreeWidget.setRootIsDecorated(False)
        self.uiMappingTreeWidget.setObjectName(_fromUtf8("uiMappingTreeWidget"))
        self.vboxlayout.addWidget(self.uiMappingTreeWidget)
        self.gridLayout_2.addWidget(self.uiMappingGroupBox, 0, 3, 3, 1)
        self.uiAddPushButton = QtGui.QPushButton(atmSwitchConfigPageWidget)
        self.uiAddPushButton.setObjectName(_fromUtf8("uiAddPushButton"))
        self.gridLayout_2.addWidget(self.uiAddPushButton, 3, 0, 1, 1)
        self.uiDeletePushButton = QtGui.QPushButton(atmSwitchConfigPageWidget)
        self.uiDeletePushButton.setEnabled(False)
        self.uiDeletePushButton.setObjectName(_fromUtf8("uiDeletePushButton"))
        self.gridLayout_2.addWidget(self.uiDeletePushButton, 3, 1, 1, 1)
        spacerItem = QtGui.QSpacerItem(213, 31, QtGui.QSizePolicy.Minimum, QtGui.QSizePolicy.Expanding)
        self.gridLayout_2.addItem(spacerItem, 4, 2, 1, 2)
        self.uiSourceGroupBox = QtGui.QGroupBox(atmSwitchConfigPageWidget)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.uiSourceGroupBox.sizePolicy().hasHeightForWidth())
        self.uiSourceGroupBox.setSizePolicy(sizePolicy)
        self.uiSourceGroupBox.setObjectName(_fromUtf8("uiSourceGroupBox"))
        self.gridlayout = QtGui.QGridLayout(self.uiSourceGroupBox)
        self.gridlayout.setObjectName(_fromUtf8("gridlayout"))
        self.uiSourcePortLabel = QtGui.QLabel(self.uiSourceGroupBox)
        self.uiSourcePortLabel.setObjectName(_fromUtf8("uiSourcePortLabel"))
        self.gridlayout.addWidget(self.uiSourcePortLabel, 0, 0, 1, 1)
        self.uiSourcePortSpinBox = QtGui.QSpinBox(self.uiSourceGroupBox)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.uiSourcePortSpinBox.sizePolicy().hasHeightForWidth())
        self.uiSourcePortSpinBox.setSizePolicy(sizePolicy)
        self.uiSourcePortSpinBox.setMinimum(0)
        self.uiSourcePortSpinBox.setMaximum(65535)
        self.uiSourcePortSpinBox.setProperty("value", 1)
        self.uiSourcePortSpinBox.setObjectName(_fromUtf8("uiSourcePortSpinBox"))
        self.gridlayout.addWidget(self.uiSourcePortSpinBox, 0, 1, 1, 1)
        self.uiSourceVPILabel = QtGui.QLabel(self.uiSourceGroupBox)
        self.uiSourceVPILabel.setObjectName(_fromUtf8("uiSourceVPILabel"))
        self.gridlayout.addWidget(self.uiSourceVPILabel, 1, 0, 1, 1)
        self.uiSourceVPISpinBox = QtGui.QSpinBox(self.uiSourceGroupBox)
        self.uiSourceVPISpinBox.setEnabled(True)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.uiSourceVPISpinBox.sizePolicy().hasHeightForWidth())
        self.uiSourceVPISpinBox.setSizePolicy(sizePolicy)
        self.uiSourceVPISpinBox.setMaximum(65535)
        self.uiSourceVPISpinBox.setProperty("value", 0)
        self.uiSourceVPISpinBox.setObjectName(_fromUtf8("uiSourceVPISpinBox"))
        self.gridlayout.addWidget(self.uiSourceVPISpinBox, 1, 1, 1, 1)
        self.uiSourceVCILabel = QtGui.QLabel(self.uiSourceGroupBox)
        self.uiSourceVCILabel.setObjectName(_fromUtf8("uiSourceVCILabel"))
        self.gridlayout.addWidget(self.uiSourceVCILabel, 2, 0, 1, 1)
        self.uiSourceVCISpinBox = QtGui.QSpinBox(self.uiSourceGroupBox)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.uiSourceVCISpinBox.sizePolicy().hasHeightForWidth())
        self.uiSourceVCISpinBox.setSizePolicy(sizePolicy)
        self.uiSourceVCISpinBox.setMaximum(65535)
        self.uiSourceVCISpinBox.setProperty("value", 100)
        self.uiSourceVCISpinBox.setObjectName(_fromUtf8("uiSourceVCISpinBox"))
        self.gridlayout.addWidget(self.uiSourceVCISpinBox, 2, 1, 1, 1)
        self.gridLayout_2.addWidget(self.uiSourceGroupBox, 1, 0, 1, 3)
        self.uiDestinationGroupBox = QtGui.QGroupBox(atmSwitchConfigPageWidget)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.uiDestinationGroupBox.sizePolicy().hasHeightForWidth())
        self.uiDestinationGroupBox.setSizePolicy(sizePolicy)
        self.uiDestinationGroupBox.setObjectName(_fromUtf8("uiDestinationGroupBox"))
        self.gridlayout1 = QtGui.QGridLayout(self.uiDestinationGroupBox)
        self.gridlayout1.setObjectName(_fromUtf8("gridlayout1"))
        self.uiDestinationPortLabel = QtGui.QLabel(self.uiDestinationGroupBox)
        self.uiDestinationPortLabel.setObjectName(_fromUtf8("uiDestinationPortLabel"))
        self.gridlayout1.addWidget(self.uiDestinationPortLabel, 0, 0, 1, 1)
        self.uiDestinationPortSpinBox = QtGui.QSpinBox(self.uiDestinationGroupBox)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.uiDestinationPortSpinBox.sizePolicy().hasHeightForWidth())
        self.uiDestinationPortSpinBox.setSizePolicy(sizePolicy)
        self.uiDestinationPortSpinBox.setMinimum(0)
        self.uiDestinationPortSpinBox.setMaximum(65535)
        self.uiDestinationPortSpinBox.setProperty("value", 10)
        self.uiDestinationPortSpinBox.setObjectName(_fromUtf8("uiDestinationPortSpinBox"))
        self.gridlayout1.addWidget(self.uiDestinationPortSpinBox, 0, 1, 1, 1)
        self.uiDestinationVPILabel = QtGui.QLabel(self.uiDestinationGroupBox)
        self.uiDestinationVPILabel.setObjectName(_fromUtf8("uiDestinationVPILabel"))
        self.gridlayout1.addWidget(self.uiDestinationVPILabel, 1, 0, 1, 1)
        self.uiDestinationVPISpinBox = QtGui.QSpinBox(self.uiDestinationGroupBox)
        self.uiDestinationVPISpinBox.setEnabled(True)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.uiDestinationVPISpinBox.sizePolicy().hasHeightForWidth())
        self.uiDestinationVPISpinBox.setSizePolicy(sizePolicy)
        self.uiDestinationVPISpinBox.setMaximum(65535)
        self.uiDestinationVPISpinBox.setProperty("value", 0)
        self.uiDestinationVPISpinBox.setObjectName(_fromUtf8("uiDestinationVPISpinBox"))
        self.gridlayout1.addWidget(self.uiDestinationVPISpinBox, 1, 1, 1, 1)
        self.uiDestinationVCILabel = QtGui.QLabel(self.uiDestinationGroupBox)
        self.uiDestinationVCILabel.setObjectName(_fromUtf8("uiDestinationVCILabel"))
        self.gridlayout1.addWidget(self.uiDestinationVCILabel, 2, 0, 1, 1)
        self.uiDestinationVCISpinBox = QtGui.QSpinBox(self.uiDestinationGroupBox)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.uiDestinationVCISpinBox.sizePolicy().hasHeightForWidth())
        self.uiDestinationVCISpinBox.setSizePolicy(sizePolicy)
        self.uiDestinationVCISpinBox.setMaximum(65535)
        self.uiDestinationVCISpinBox.setProperty("value", 200)
        self.uiDestinationVCISpinBox.setObjectName(_fromUtf8("uiDestinationVCISpinBox"))
        self.gridlayout1.addWidget(self.uiDestinationVCISpinBox, 2, 1, 1, 1)
        self.gridLayout_2.addWidget(self.uiDestinationGroupBox, 2, 0, 1, 3)

        self.retranslateUi(atmSwitchConfigPageWidget)
        QtCore.QMetaObject.connectSlotsByName(atmSwitchConfigPageWidget)
        atmSwitchConfigPageWidget.setTabOrder(self.uiVPICheckBox, self.uiSourcePortSpinBox)
        atmSwitchConfigPageWidget.setTabOrder(self.uiSourcePortSpinBox, self.uiSourceVPISpinBox)
        atmSwitchConfigPageWidget.setTabOrder(self.uiSourceVPISpinBox, self.uiSourceVCISpinBox)
        atmSwitchConfigPageWidget.setTabOrder(self.uiSourceVCISpinBox, self.uiDestinationPortSpinBox)
        atmSwitchConfigPageWidget.setTabOrder(self.uiDestinationPortSpinBox, self.uiDestinationVPISpinBox)
        atmSwitchConfigPageWidget.setTabOrder(self.uiDestinationVPISpinBox, self.uiDestinationVCISpinBox)
        atmSwitchConfigPageWidget.setTabOrder(self.uiDestinationVCISpinBox, self.uiAddPushButton)
        atmSwitchConfigPageWidget.setTabOrder(self.uiAddPushButton, self.uiDeletePushButton)

    def retranslateUi(self, atmSwitchConfigPageWidget):
        atmSwitchConfigPageWidget.setWindowTitle(_translate("atmSwitchConfigPageWidget", "ATM Switch", None))
        self.uiGeneralGroupBox.setTitle(_translate("atmSwitchConfigPageWidget", "General", None))
        self.uiNameLabel.setText(_translate("atmSwitchConfigPageWidget", "Name:", None))
        self.uiVPICheckBox.setText(_translate("atmSwitchConfigPageWidget", "Use VPI only (VP tunnel)", None))
        self.uiMappingGroupBox.setTitle(_translate("atmSwitchConfigPageWidget", "Mapping", None))
        self.uiMappingTreeWidget.headerItem().setText(0, _translate("atmSwitchConfigPageWidget", "Port:VPI:VCI", None))
        self.uiMappingTreeWidget.headerItem().setText(1, _translate("atmSwitchConfigPageWidget", "Port:VPI:VCI", None))
        self.uiAddPushButton.setText(_translate("atmSwitchConfigPageWidget", "&Add", None))
        self.uiDeletePushButton.setText(_translate("atmSwitchConfigPageWidget", "&Delete", None))
        self.uiSourceGroupBox.setTitle(_translate("atmSwitchConfigPageWidget", "Source", None))
        self.uiSourcePortLabel.setText(_translate("atmSwitchConfigPageWidget", "Port:", None))
        self.uiSourceVPILabel.setText(_translate("atmSwitchConfigPageWidget", "VPI:", None))
        self.uiSourceVCILabel.setText(_translate("atmSwitchConfigPageWidget", "VCI:", None))
        self.uiDestinationGroupBox.setTitle(_translate("atmSwitchConfigPageWidget", "Destination", None))
        self.uiDestinationPortLabel.setText(_translate("atmSwitchConfigPageWidget", "Port:", None))
        self.uiDestinationVPILabel.setText(_translate("atmSwitchConfigPageWidget", "VPI:", None))
        self.uiDestinationVCILabel.setText(_translate("atmSwitchConfigPageWidget", "VCI:", None))



# -*- coding: utf-8 -*-
#
# Copyright (C) 2014 GNS3 Technologies Inc.
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from ..qt import QtGui
from ..version import __version__
from ..ui.about_dialog_ui import Ui_AboutDialog


class AboutDialog(QtGui.QDialog, Ui_AboutDialog):

    """
    About dialog.
    """

    def __init__(self, parent):

        QtGui.QDialog.__init__(self, parent)
        self.setupUi(self)

        # dynamically add the current version number
        text = self.uiAboutTextLabel.text()
        text = text.replace("%VERSION%", __version__)
        self.uiAboutTextLabel.setText(text)



# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file '/home/grossmj/workspace/git/gns3-gui/gns3/modules/dynamips/ui/atm_bridge_configuration_page.ui'
#
# Created: Sun Mar 16 11:16:57 2014
#      by: PyQt4 UI code generator 4.10
#
# WARNING! All changes made in this file will be lost!

from PyQt4 import QtCore, QtGui

try:
    _fromUtf8 = QtCore.QString.fromUtf8
except AttributeError:
    def _fromUtf8(s):
        return s

try:
    _encoding = QtGui.QApplication.UnicodeUTF8

    def _translate(context, text, disambig):
        return QtGui.QApplication.translate(context, text, disambig, _encoding)
except AttributeError:
    def _translate(context, text, disambig):
        return QtGui.QApplication.translate(context, text, disambig)


class Ui_atmBridgeConfigPageWidget(object):

    def setupUi(self, atmBridgeConfigPageWidget):
        atmBridgeConfigPageWidget.setObjectName(_fromUtf8("atmBridgeConfigPageWidget"))
        atmBridgeConfigPageWidget.resize(432, 358)
        self.gridLayout_2 = QtGui.QGridLayout(atmBridgeConfigPageWidget)
        self.gridLayout_2.setObjectName(_fromUtf8("gridLayout_2"))
        self.uiMappingGroupBox = QtGui.QGroupBox(atmBridgeConfigPageWidget)
        self.uiMappingGroupBox.setObjectName(_fromUtf8("uiMappingGroupBox"))
        self.vboxlayout = QtGui.QVBoxLayout(self.uiMappingGroupBox)
        self.vboxlayout.setObjectName(_fromUtf8("vboxlayout"))
        self.uiMappingTreeWidget = QtGui.QTreeWidget(self.uiMappingGroupBox)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.uiMappingTreeWidget.sizePolicy().hasHeightForWidth())
        self.uiMappingTreeWidget.setSizePolicy(sizePolicy)
        self.uiMappingTreeWidget.setRootIsDecorated(False)
        self.uiMappingTreeWidget.setObjectName(_fromUtf8("uiMappingTreeWidget"))
        self.vboxlayout.addWidget(self.uiMappingTreeWidget)
        self.gridLayout_2.addWidget(self.uiMappingGroupBox, 0, 2, 3, 1)
        self.uiEthernetGroupBox = QtGui.QGroupBox(atmBridgeConfigPageWidget)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.uiEthernetGroupBox.sizePolicy().hasHeightForWidth())
        self.uiEthernetGroupBox.setSizePolicy(sizePolicy)
        self.uiEthernetGroupBox.setObjectName(_fromUtf8("uiEthernetGroupBox"))
        self.gridlayout = QtGui.QGridLayout(self.uiEthernetGroupBox)
        self.gridlayout.setObjectName(_fromUtf8("gridlayout"))
        self.uiEthernetPortLabel = QtGui.QLabel(self.uiEthernetGroupBox)
        self.uiEthernetPortLabel.setObjectName(_fromUtf8("uiEthernetPortLabel"))
        self.gridlayout.addWidget(self.uiEthernetPortLabel, 0, 0, 1, 1)
        self.uiEthernetPortSpinBox = QtGui.QSpinBox(self.uiEthernetGroupBox)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.uiEthernetPortSpinBox.sizePolicy().hasHeightForWidth())
        self.uiEthernetPortSpinBox.setSizePolicy(sizePolicy)
        self.uiEthernetPortSpinBox.setMinimum(0)
        self.uiEthernetPortSpinBox.setMaximum(65535)
        self.uiEthernetPortSpinBox.setProperty("value", 1)
        self.uiEthernetPortSpinBox.setObjectName(_fromUtf8("uiEthernetPortSpinBox"))
        self.gridlayout.addWidget(self.uiEthernetPortSpinBox, 0, 1, 1, 1)
        self.gridLayout_2.addWidget(self.uiEthernetGroupBox, 1, 0, 1, 2)
        self.uiATMGroupBox = QtGui.QGroupBox(atmBridgeConfigPageWidget)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.uiATMGroupBox.sizePolicy().hasHeightForWidth())
        self.uiATMGroupBox.setSizePolicy(sizePolicy)
        self.uiATMGroupBox.setObjectName(_fromUtf8("uiATMGroupBox"))
        self.gridlayout1 = QtGui.QGridLayout(self.uiATMGroupBox)
        self.gridlayout1.setObjectName(_fromUtf8("gridlayout1"))
        self.uiATMPortLabel = QtGui.QLabel(self.uiATMGroupBox)
        self.uiATMPortLabel.setObjectName(_fromUtf8("uiATMPortLabel"))
        self.gridlayout1.addWidget(self.uiATMPortLabel, 0, 0, 1, 1)
        self.uiATMPortSpinBox = QtGui.QSpinBox(self.uiATMGroupBox)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.uiATMPortSpinBox.sizePolicy().hasHeightForWidth())
        self.uiATMPortSpinBox.setSizePolicy(sizePolicy)
        self.uiATMPortSpinBox.setMinimum(0)
        self.uiATMPortSpinBox.setMaximum(65535)
        self.uiATMPortSpinBox.setProperty("value", 10)
        self.uiATMPortSpinBox.setObjectName(_fromUtf8("uiATMPortSpinBox"))
        self.gridlayout1.addWidget(self.uiATMPortSpinBox, 0, 1, 1, 1)
        self.uiATMVPILabel = QtGui.QLabel(self.uiATMGroupBox)
        self.uiATMVPILabel.setObjectName(_fromUtf8("uiATMVPILabel"))
        self.gridlayout1.addWidget(self.uiATMVPILabel, 1, 0, 1, 1)
        self.uiATMVPISpinBox = QtGui.QSpinBox(self.uiATMGroupBox)
        self.uiATMVPISpinBox.setEnabled(True)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.uiATMVPISpinBox.sizePolicy().hasHeightForWidth())
        self.uiATMVPISpinBox.setSizePolicy(sizePolicy)
        self.uiATMVPISpinBox.setMinimum(0)
        self.uiATMVPISpinBox.setMaximum(65535)
        self.uiATMVPISpinBox.setSingleStep(1)
        self.uiATMVPISpinBox.setProperty("value", 0)
        self.uiATMVPISpinBox.setObjectName(_fromUtf8("uiATMVPISpinBox"))
        self.gridlayout1.addWidget(self.uiATMVPISpinBox, 1, 1, 1, 1)
        self.uiATMVCILabel = QtGui.QLabel(self.uiATMGroupBox)
        self.uiATMVCILabel.setObjectName(_fromUtf8("uiATMVCILabel"))
        self.gridlayout1.addWidget(self.uiATMVCILabel, 2, 0, 1, 1)
        self.uiATMVCISpinBox = QtGui.QSpinBox(self.uiATMGroupBox)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.uiATMVCISpinBox.sizePolicy().hasHeightForWidth())
        self.uiATMVCISpinBox.setSizePolicy(sizePolicy)
        self.uiATMVCISpinBox.setMaximum(65535)
        self.uiATMVCISpinBox.setProperty("value", 100)
        self.uiATMVCISpinBox.setObjectName(_fromUtf8("uiATMVCISpinBox"))
        self.gridlayout1.addWidget(self.uiATMVCISpinBox, 2, 1, 1, 1)
        self.gridLayout_2.addWidget(self.uiATMGroupBox, 2, 0, 1, 2)
        self.uiAddPushButton = QtGui.QPushButton(atmBridgeConfigPageWidget)
        self.uiAddPushButton.setObjectName(_fromUtf8("uiAddPushButton"))
        self.gridLayout_2.addWidget(self.uiAddPushButton, 3, 0, 1, 1)
        self.uiDeletePushButton = QtGui.QPushButton(atmBridgeConfigPageWidget)
        self.uiDeletePushButton.setEnabled(False)
        self.uiDeletePushButton.setObjectName(_fromUtf8("uiDeletePushButton"))
        self.gridLayout_2.addWidget(self.uiDeletePushButton, 3, 1, 1, 1)
        spacerItem = QtGui.QSpacerItem(371, 121, QtGui.QSizePolicy.Minimum, QtGui.QSizePolicy.Expanding)
        self.gridLayout_2.addItem(spacerItem, 4, 0, 1, 3)
        self.uiGeneralGroupBox = QtGui.QGroupBox(atmBridgeConfigPageWidget)
        self.uiGeneralGroupBox.setObjectName(_fromUtf8("uiGeneralGroupBox"))
        self.gridLayout = QtGui.QGridLayout(self.uiGeneralGroupBox)
        self.gridLayout.setObjectName(_fromUtf8("gridLayout"))
        self.uiNameLabel = QtGui.QLabel(self.uiGeneralGroupBox)
        self.uiNameLabel.setObjectName(_fromUtf8("uiNameLabel"))
        self.gridLayout.addWidget(self.uiNameLabel, 0, 0, 1, 1)
        self.uiNameLineEdit = QtGui.QLineEdit(self.uiGeneralGroupBox)
        self.uiNameLineEdit.setObjectName(_fromUtf8("uiNameLineEdit"))
        self.gridLayout.addWidget(self.uiNameLineEdit, 0, 1, 1, 1)
        self.gridLayout_2.addWidget(self.uiGeneralGroupBox, 0, 0, 1, 2)

        self.retranslateUi(atmBridgeConfigPageWidget)
        QtCore.QMetaObject.connectSlotsByName(atmBridgeConfigPageWidget)
        atmBridgeConfigPageWidget.setTabOrder(self.uiEthernetPortSpinBox, self.uiATMPortSpinBox)
        atmBridgeConfigPageWidget.setTabOrder(self.uiATMPortSpinBox, self.uiATMVPISpinBox)
        atmBridgeConfigPageWidget.setTabOrder(self.uiATMVPISpinBox, self.uiATMVCISpinBox)
        atmBridgeConfigPageWidget.setTabOrder(self.uiATMVCISpinBox, self.uiAddPushButton)
        atmBridgeConfigPageWidget.setTabOrder(self.uiAddPushButton, self.uiDeletePushButton)

    def retranslateUi(self, atmBridgeConfigPageWidget):
        atmBridgeConfigPageWidget.setWindowTitle(_translate("atmBridgeConfigPageWidget", "ATM Bridge", None))
        self.uiMappingGroupBox.setTitle(_translate("atmBridgeConfigPageWidget", "Mapping", None))
        self.uiMappingTreeWidget.headerItem().setText(0, _translate("atmBridgeConfigPageWidget", "Ethernet Port", None))
        self.uiMappingTreeWidget.headerItem().setText(1, _translate("atmBridgeConfigPageWidget", "Port:VPI:VCI", None))
        self.uiEthernetGroupBox.setTitle(_translate("atmBridgeConfigPageWidget", "Ethernet side", None))
        self.uiEthernetPortLabel.setText(_translate("atmBridgeConfigPageWidget", "Port:", None))
        self.uiATMGroupBox.setTitle(_translate("atmBridgeConfigPageWidget", "ATM side", None))
        self.uiATMPortLabel.setText(_translate("atmBridgeConfigPageWidget", "Port:", None))
        self.uiATMVPILabel.setText(_translate("atmBridgeConfigPageWidget", "VPI:", None))
        self.uiATMVCILabel.setText(_translate("atmBridgeConfigPageWidget", "VCI:", None))
        self.uiAddPushButton.setText(_translate("atmBridgeConfigPageWidget", "&Add", None))
        self.uiDeletePushButton.setText(_translate("atmBridgeConfigPageWidget", "&Delete", None))
        self.uiGeneralGroupBox.setTitle(_translate("atmBridgeConfigPageWidget", "General", None))
        self.uiNameLabel.setText(_translate("atmBridgeConfigPageWidget", "Name:", None))



# -*- coding: utf-8 -*-
#
# Copyright (C) 2014 GNS3 Technologies Inc.
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

"""
Thread to copy or move files without blocking the GUI.
"""

import shutil
from ..qt import QtCore

import logging
log = logging.getLogger(__name__)


class FileCopyThread(QtCore.QThread):

    """
    Thread to copy a file.

    :param source: path to the source file
    :param destination: path to the destination file
    """

    # signals to update the progress dialog.
    error = QtCore.pyqtSignal(str, bool)
    completed = QtCore.pyqtSignal()
    update = QtCore.pyqtSignal(int)

    def __init__(self, source, destination):

        QtCore.QThread.__init__(self)
        self._is_running = False
        self._source = source
        self._destination = destination

    def run(self):
        """
        Thread starting point.
        """

        self._is_running = True
        try:
            shutil.copyfile(self._source, self._destination)
        except OSError as e:
            log.warning("cannot copy: {}".format(e))
            self.error.emit("Could not copy file to {}: {}".format(self._destination, e), False)
        self.completed.emit()

    def stop(self):
        """
        Stops this thread as soon as possible.
        """

        self._is_running = False



# -*- coding: utf-8 -*-
#
# Copyright (C) 2014 GNS3 Technologies Inc.
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

"""
Functions to start external serial console terminals.
"""

import re
import os
import sys
import shlex
import subprocess
import tempfile
from .main_window import MainWindow

import logging
log = logging.getLogger(__name__)


# TODO: support more than just Vbox (Qemu maybe?)
def serialConsole(vmname):
    """
    :param vmname: Virtual machine name.

    Start a Serial console program.
    """

    command = MainWindow.instance().serialConsoleCommand()
    if not command:
        return

    p = re.compile('\s+', re.UNICODE)
    pipe_name = p.sub("_", vmname)
    if sys.platform.startswith('win'):
        pipe_name = r"\\.\pipe\VBOX\{}".format(pipe_name)
    else:
        pipe_name = os.path.join(tempfile.gettempdir(), "pipe_{}".format(pipe_name))

    # replace the place-holders by the actual values
    command = command.replace("%s", pipe_name)
    command = command.replace("%d", vmname)
    log.info('starting serial console "{}"'.format(command))

    try:
        if sys.platform.startswith("win"):
            # use the string on Windows
            subprocess.Popen(command)
        else:
            # use arguments on other platforms
            args = shlex.split(command)
            subprocess.Popen(args)
    except (OSError, subprocess.SubprocessError) as e:
        log.warning('could not start serial console "{}": {}'.format(command, e))
        raise



# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file '/home/grossmj/PycharmProjects/gns3-gui/gns3/ui/exec_command_dialog.ui'
#
# Created: Mon Oct 13 17:41:51 2014
#      by: PyQt4 UI code generator 4.10.4
#
# WARNING! All changes made in this file will be lost!

from PyQt4 import QtCore, QtGui

try:
    _fromUtf8 = QtCore.QString.fromUtf8
except AttributeError:
    def _fromUtf8(s):
        return s

try:
    _encoding = QtGui.QApplication.UnicodeUTF8

    def _translate(context, text, disambig):
        return QtGui.QApplication.translate(context, text, disambig, _encoding)
except AttributeError:
    def _translate(context, text, disambig):
        return QtGui.QApplication.translate(context, text, disambig)


class Ui_ExecCommandDialog(object):

    def setupUi(self, ExecCommandDialog):
        ExecCommandDialog.setObjectName(_fromUtf8("ExecCommandDialog"))
        ExecCommandDialog.resize(651, 343)
        ExecCommandDialog.setModal(True)
        self.gridLayout = QtGui.QGridLayout(ExecCommandDialog)
        self.gridLayout.setObjectName(_fromUtf8("gridLayout"))
        self.uiOutputTextEdit = QtGui.QPlainTextEdit(ExecCommandDialog)
        self.uiOutputTextEdit.setObjectName(_fromUtf8("uiOutputTextEdit"))
        self.gridLayout.addWidget(self.uiOutputTextEdit, 0, 0, 1, 2)
        self.uiButtonBox = QtGui.QDialogButtonBox(ExecCommandDialog)
        self.uiButtonBox.setOrientation(QtCore.Qt.Horizontal)
        self.uiButtonBox.setStandardButtons(QtGui.QDialogButtonBox.Ok)
        self.uiButtonBox.setObjectName(_fromUtf8("uiButtonBox"))
        self.gridLayout.addWidget(self.uiButtonBox, 1, 1, 1, 1)

        self.retranslateUi(ExecCommandDialog)
        QtCore.QObject.connect(self.uiButtonBox, QtCore.SIGNAL(_fromUtf8("accepted()")), ExecCommandDialog.accept)
        QtCore.QObject.connect(self.uiButtonBox, QtCore.SIGNAL(_fromUtf8("rejected()")), ExecCommandDialog.reject)
        QtCore.QMetaObject.connectSlotsByName(ExecCommandDialog)

    def retranslateUi(self, ExecCommandDialog):
        ExecCommandDialog.setWindowTitle(_translate("ExecCommandDialog", "Command execution", None))

from . import resources_rc



# -*- coding: utf-8 -*-
from ..ui.cloud_preferences_page_ui import Ui_CloudPreferencesPageWidget
from ..settings import CLOUD_PROVIDERS
from ..utils import import_from_string

from ..qt import QtCore, QtGui


class CloudPreferencesPage(QtGui.QWidget, Ui_CloudPreferencesPageWidget):

    """
    QWidget configuration page for cloud preferences.
    """

    def __init__(self, parent=None):

        QtGui.QWidget.__init__(self)
        self.setupUi(self)

        # the list containing provider controller classes
        self.provider_controllers = {}
        # map region ids to combobox indexes
        self.region_index_id = []
        # map provider ids to combobox indexes
        self.provider_index_id = []
        # map image ids to combobox indexes
        self.image_index_id = []
        # map flavor ids to combobox indexes
        self.flavor_index_id = []

        # insert Terms&Condition link inside the checkbox
        self.uiTermsLabel.setText('Accept <a href="{}">Terms and Conditions</a>'.format('#'))

        from ..main_window import MainWindow
        self.settings = MainWindow.instance().cloudSettings()

    def _get_region_index(self, region_id):
        try:
            return self.region_index_id.index(region_id)
        except ValueError:
            return -1

    def _get_image_index(self, image_name):
        try:
            return self.image_index_id.index(image_name)
        except ValueError:
            return -1

    def _get_flavor_index(self, flavor_id):
        try:
            return self.flavor_index_id.index(flavor_id)
        except ValueError:
            return -1

    def _store_api_key(self):
        """
        helper method, returns whether user wants to store api keys or not
        """
        return self.uiRememberAPIKeyRadioButton.isChecked()

    def _terms_accepted(self):
        return self.uiTermsCheckBox.checkState() == QtCore.Qt.Checked

    def _validate(self):
        """
        Check if settings are ok
        """
        errors = ""
        can_authenticate = self.uiUserNameLineEdit.text() and self.uiAPIKeyLineEdit.text()
        remember_have_been_set = self.uiRememberAPIKeyRadioButton.isChecked() or \
            self.uiForgetAPIKeyRadioButton.isChecked()

        if can_authenticate and not remember_have_been_set:
            errors += "Please choose if you want to persist your API keys or not.\n"

        if can_authenticate and not self._terms_accepted():
            errors += "You have to accept Terms and Conditions to proceed.\n"

        if errors:
            QtGui.QMessageBox.critical(self, "Cloud Preferences", errors)
            return False
        return True

    def loadPreferences(self):
        """
        Load cloud preferences and populate the panel
        """
        self.provider_controllers.clear()

        # fill provider combobox
        self.provider_index_id = [""]
        self.uiCloudProviderComboBox.addItem("Select provider...")
        for k, v in CLOUD_PROVIDERS.items():
            self.uiCloudProviderComboBox.addItem(v[0])
            self.provider_controllers[k] = import_from_string(v[1])
            self.provider_index_id.append(k)

        # do not select anything the very first time this page is loaded
        if not self.settings['cloud_store_api_key_chosen']:
            return

        username = self.settings['cloud_user_name']
        apikey = self.settings['cloud_api_key']
        provider_id = self.settings['cloud_provider']
        region = self.settings['cloud_region']
        default_image = self.settings['default_image']
        default_flavor = self.settings['default_flavor']
        new_instance_flavor = self.settings['new_instance_flavor']

        # instance a provider controller and try to use it
        try:
            provider = self.provider_controllers[provider_id](username, apikey)
            if provider.authenticate():
                provider.set_region(region)
                # fill region combo box
                self.region_index_id = [""]
                self.uiRegionComboBox.addItem("Select region...")
                for r in provider.list_regions():
                    api_region_names = list(r.keys())
                    api_libcloud_names = list(r.values())
                    self.uiRegionComboBox.addItem(api_region_names[0])
                    self.region_index_id.append(api_libcloud_names[0])
                # fill image template list
                self.image_index_id = ["cc6e0096-84f9-4beb-a21e-d80a11a769d8"]
                self.uiImageTemplateComboBox.addItem("Ubuntu 14.04")
                self.uiImageTemplateComboBox.setCurrentIndex(0)
                # fill flavor comboboxes
                for id, name in provider.list_flavors().items():
                    self.uiInstanceFlavorComboBox.addItem(name)
                    self.uiNewInstanceFlavorComboBox.addItem(name)
                    self.flavor_index_id.append(id)
        except KeyError:
            # username/apikey/provider are not set
            pass

        # populate all the cloud stuff
        self.uiUserNameLineEdit.setText(username)
        self.uiAPIKeyLineEdit.setText(apikey)
        self.uiCloudProviderComboBox.setCurrentIndex(self.provider_index_id.index(provider_id))
        self.uiRegionComboBox.setCurrentIndex(self._get_region_index(region))
        if self.settings.get("cloud_store_api_key"):
            self.uiRememberAPIKeyRadioButton.setChecked(True)
        else:
            self.uiForgetAPIKeyRadioButton.setChecked(True)
        self.uiNumOfInstancesSpinBox.setValue(self.settings['instances_per_project'])
        self.uiTermsCheckBox.setChecked(self.settings['accepted_terms'])
        self.uiTimeoutSpinBox.setValue(self.settings['instance_timeout'])
        self.uiImageTemplateComboBox.setCurrentIndex(self._get_image_index(default_image))

        idx = self._get_flavor_index(default_flavor)
        if idx < 0:
            idx = 0
        self.uiInstanceFlavorComboBox.setCurrentIndex(idx)

        idx = self._get_flavor_index(new_instance_flavor)
        if idx < 0:
            idx = 0
        self.uiNewInstanceFlavorComboBox.setCurrentIndex(idx)

    def savePreferences(self):
        """
        Save cloud preferences
        """
        if self._validate():
            self.settings['cloud_user_name'] = self.uiUserNameLineEdit.text()
            self.settings['cloud_api_key'] = self.uiAPIKeyLineEdit.text()
            self.settings['cloud_store_api_key'] = True
            if self.uiCloudProviderComboBox.currentIndex() >= 0:
                self.settings['cloud_provider'] = \
                    self.provider_index_id[self.uiCloudProviderComboBox.currentIndex()]
            if self.uiRegionComboBox.currentIndex() >= 0:
                self.settings['cloud_region'] = \
                    self.region_index_id[self.uiRegionComboBox.currentIndex()]
            self.settings['instances_per_project'] = self.uiNumOfInstancesSpinBox.value()
            if len(self.flavor_index_id):
                self.settings['default_flavor'] = self.flavor_index_id[self.uiInstanceFlavorComboBox.currentIndex()]
                self.settings['new_instance_flavor'] = self.flavor_index_id[self.uiNewInstanceFlavorComboBox.currentIndex()]
            self.settings['accepted_terms'] = self.uiTermsCheckBox.isChecked()
            self.settings['instance_timeout'] = self.uiTimeoutSpinBox.value()
            if self.uiImageTemplateComboBox.currentIndex() >= 0:
                self.settings['default_image'] = \
                    self.image_index_id[self.uiImageTemplateComboBox.currentIndex()]

            if not self.settings['cloud_store_api_key_chosen']:
                # user made a choice at this point
                self.settings['cloud_store_api_key_chosen'] = True

            from ..main_window import MainWindow
            MainWindow.instance().setCloudSettings(self.settings, persist=self._store_api_key())

            return True
        return False
